# coding: utf-8
import pprint
import six
from enum import Enum



class ShopifySubscriber:

    swagger_types = {
    
        'created_on': 'datetime',
        'email_address': 'str',
        'external_gid': 'str',
        'external_id': 'str',
        'id': 'int',
        'linked_space_id': 'int',
        'phone_number': 'str',
        'planned_purge_date': 'datetime',
        'shop': 'int',
        'state': 'ShopifySubscriberState',
        'version': 'int',
    }

    attribute_map = {
        'created_on': 'createdOn','email_address': 'emailAddress','external_gid': 'externalGid','external_id': 'externalId','id': 'id','linked_space_id': 'linkedSpaceId','phone_number': 'phoneNumber','planned_purge_date': 'plannedPurgeDate','shop': 'shop','state': 'state','version': 'version',
    }

    
    _created_on = None
    _email_address = None
    _external_gid = None
    _external_id = None
    _id = None
    _linked_space_id = None
    _phone_number = None
    _planned_purge_date = None
    _shop = None
    _state = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.created_on = kwargs.get('created_on', None)
        self.email_address = kwargs.get('email_address', None)
        self.external_gid = kwargs.get('external_gid', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.phone_number = kwargs.get('phone_number', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.shop = kwargs.get('shop', None)
        self.state = kwargs.get('state', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def created_on(self):
        """Gets the created_on of this ShopifySubscriber.

            

        :return: The created_on of this ShopifySubscriber.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this ShopifySubscriber.

            

        :param created_on: The created_on of this ShopifySubscriber.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def email_address(self):
        """Gets the email_address of this ShopifySubscriber.

            

        :return: The email_address of this ShopifySubscriber.
        :rtype: str
        """
        return self._email_address

    @email_address.setter
    def email_address(self, email_address):
        """Sets the email_address of this ShopifySubscriber.

            

        :param email_address: The email_address of this ShopifySubscriber.
        :type: str
        """
        if email_address is not None and len(email_address) > 254:
            raise ValueError("Invalid value for `email_address`, length must be less than or equal to `254`")

        self._email_address = email_address
    
    @property
    def external_gid(self):
        """Gets the external_gid of this ShopifySubscriber.

            

        :return: The external_gid of this ShopifySubscriber.
        :rtype: str
        """
        return self._external_gid

    @external_gid.setter
    def external_gid(self, external_gid):
        """Sets the external_gid of this ShopifySubscriber.

            

        :param external_gid: The external_gid of this ShopifySubscriber.
        :type: str
        """

        self._external_gid = external_gid
    
    @property
    def external_id(self):
        """Gets the external_id of this ShopifySubscriber.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :return: The external_id of this ShopifySubscriber.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this ShopifySubscriber.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :param external_id: The external_id of this ShopifySubscriber.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this ShopifySubscriber.

            A unique identifier for the object.

        :return: The id of this ShopifySubscriber.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ShopifySubscriber.

            A unique identifier for the object.

        :param id: The id of this ShopifySubscriber.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this ShopifySubscriber.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this ShopifySubscriber.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this ShopifySubscriber.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this ShopifySubscriber.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def phone_number(self):
        """Gets the phone_number of this ShopifySubscriber.

            

        :return: The phone_number of this ShopifySubscriber.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """Sets the phone_number of this ShopifySubscriber.

            

        :param phone_number: The phone_number of this ShopifySubscriber.
        :type: str
        """
        if phone_number is not None and len(phone_number) > 254:
            raise ValueError("Invalid value for `phone_number`, length must be less than or equal to `254`")

        self._phone_number = phone_number
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this ShopifySubscriber.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this ShopifySubscriber.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this ShopifySubscriber.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this ShopifySubscriber.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def shop(self):
        """Gets the shop of this ShopifySubscriber.

            

        :return: The shop of this ShopifySubscriber.
        :rtype: int
        """
        return self._shop

    @shop.setter
    def shop(self, shop):
        """Sets the shop of this ShopifySubscriber.

            

        :param shop: The shop of this ShopifySubscriber.
        :type: int
        """

        self._shop = shop
    
    @property
    def state(self):
        """Gets the state of this ShopifySubscriber.

            The object's current state.

        :return: The state of this ShopifySubscriber.
        :rtype: ShopifySubscriberState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this ShopifySubscriber.

            The object's current state.

        :param state: The state of this ShopifySubscriber.
        :type: ShopifySubscriberState
        """

        self._state = state
    
    @property
    def version(self):
        """Gets the version of this ShopifySubscriber.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this ShopifySubscriber.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ShopifySubscriber.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this ShopifySubscriber.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ShopifySubscriber, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ShopifySubscriber):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class TransactionInvoiceReplacement:

    swagger_types = {
    
        'billing_address': 'AddressCreate',
        'due_on': 'datetime',
        'external_id': 'str',
        'line_items': 'list[LineItemCreate]',
        'merchant_reference': 'str',
        'sent_to_customer': 'bool',
    }

    attribute_map = {
        'billing_address': 'billingAddress','due_on': 'dueOn','external_id': 'externalId','line_items': 'lineItems','merchant_reference': 'merchantReference','sent_to_customer': 'sentToCustomer',
    }

    
    _billing_address = None
    _due_on = None
    _external_id = None
    _line_items = None
    _merchant_reference = None
    _sent_to_customer = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.billing_address = kwargs.get('billing_address', None)
        self.due_on = kwargs.get('due_on', None)
        self.external_id = kwargs.get('external_id')

        self.line_items = kwargs.get('line_items')

        self.merchant_reference = kwargs.get('merchant_reference', None)
        self.sent_to_customer = kwargs.get('sent_to_customer', None)
        

    
    @property
    def billing_address(self):
        """Gets the billing_address of this TransactionInvoiceReplacement.

            The address associated with the invoice, used for billing purposes.

        :return: The billing_address of this TransactionInvoiceReplacement.
        :rtype: AddressCreate
        """
        return self._billing_address

    @billing_address.setter
    def billing_address(self, billing_address):
        """Sets the billing_address of this TransactionInvoiceReplacement.

            The address associated with the invoice, used for billing purposes.

        :param billing_address: The billing_address of this TransactionInvoiceReplacement.
        :type: AddressCreate
        """

        self._billing_address = billing_address
    
    @property
    def due_on(self):
        """Gets the due_on of this TransactionInvoiceReplacement.

            The due date for payment of the invoice.

        :return: The due_on of this TransactionInvoiceReplacement.
        :rtype: datetime
        """
        return self._due_on

    @due_on.setter
    def due_on(self, due_on):
        """Sets the due_on of this TransactionInvoiceReplacement.

            The due date for payment of the invoice.

        :param due_on: The due_on of this TransactionInvoiceReplacement.
        :type: datetime
        """

        self._due_on = due_on
    
    @property
    def external_id(self):
        """Gets the external_id of this TransactionInvoiceReplacement.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :return: The external_id of this TransactionInvoiceReplacement.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this TransactionInvoiceReplacement.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :param external_id: The external_id of this TransactionInvoiceReplacement.
        :type: str
        """
        if external_id is None:
            raise ValueError("Invalid value for `external_id`, must not be `None`")
        if external_id is not None and len(external_id) > 100:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `100`")
        if external_id is not None and len(external_id) < 1:
            raise ValueError("Invalid value for `external_id`, length must be greater than or equal to `1`")

        self._external_id = external_id
    
    @property
    def line_items(self):
        """Gets the line_items of this TransactionInvoiceReplacement.

            The invoiced line items that will appear on the invoice document.

        :return: The line_items of this TransactionInvoiceReplacement.
        :rtype: list[LineItemCreate]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this TransactionInvoiceReplacement.

            The invoiced line items that will appear on the invoice document.

        :param line_items: The line_items of this TransactionInvoiceReplacement.
        :type: list[LineItemCreate]
        """
        if line_items is None:
            raise ValueError("Invalid value for `line_items`, must not be `None`")

        self._line_items = line_items
    
    @property
    def merchant_reference(self):
        """Gets the merchant_reference of this TransactionInvoiceReplacement.

            The merchant's reference used to identify the invoice.

        :return: The merchant_reference of this TransactionInvoiceReplacement.
        :rtype: str
        """
        return self._merchant_reference

    @merchant_reference.setter
    def merchant_reference(self, merchant_reference):
        """Sets the merchant_reference of this TransactionInvoiceReplacement.

            The merchant's reference used to identify the invoice.

        :param merchant_reference: The merchant_reference of this TransactionInvoiceReplacement.
        :type: str
        """
        if merchant_reference is not None and len(merchant_reference) > 100:
            raise ValueError("Invalid value for `merchant_reference`, length must be less than or equal to `100`")

        self._merchant_reference = merchant_reference
    
    @property
    def sent_to_customer(self):
        """Gets the sent_to_customer of this TransactionInvoiceReplacement.

            Whether the invoice will be sent to the customer via email.

        :return: The sent_to_customer of this TransactionInvoiceReplacement.
        :rtype: bool
        """
        return self._sent_to_customer

    @sent_to_customer.setter
    def sent_to_customer(self, sent_to_customer):
        """Sets the sent_to_customer of this TransactionInvoiceReplacement.

            Whether the invoice will be sent to the customer via email.

        :param sent_to_customer: The sent_to_customer of this TransactionInvoiceReplacement.
        :type: bool
        """

        self._sent_to_customer = sent_to_customer
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(TransactionInvoiceReplacement, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, TransactionInvoiceReplacement):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class DebtCollectionReceipt:

    swagger_types = {
    
        'amount': 'float',
        'created_by': 'int',
        'created_on': 'datetime',
        'debt_collection_case': 'int',
        'external_id': 'str',
        'id': 'int',
        'linked_space_id': 'int',
        'planned_purge_date': 'datetime',
        'source': 'int',
        'version': 'int',
    }

    attribute_map = {
        'amount': 'amount','created_by': 'createdBy','created_on': 'createdOn','debt_collection_case': 'debtCollectionCase','external_id': 'externalId','id': 'id','linked_space_id': 'linkedSpaceId','planned_purge_date': 'plannedPurgeDate','source': 'source','version': 'version',
    }

    
    _amount = None
    _created_by = None
    _created_on = None
    _debt_collection_case = None
    _external_id = None
    _id = None
    _linked_space_id = None
    _planned_purge_date = None
    _source = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.amount = kwargs.get('amount', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.debt_collection_case = kwargs.get('debt_collection_case', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.source = kwargs.get('source', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def amount(self):
        """Gets the amount of this DebtCollectionReceipt.

            The amount that was collected.

        :return: The amount of this DebtCollectionReceipt.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this DebtCollectionReceipt.

            The amount that was collected.

        :param amount: The amount of this DebtCollectionReceipt.
        :type: float
        """

        self._amount = amount
    
    @property
    def created_by(self):
        """Gets the created_by of this DebtCollectionReceipt.

            The ID of the user the receipt was created by.

        :return: The created_by of this DebtCollectionReceipt.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this DebtCollectionReceipt.

            The ID of the user the receipt was created by.

        :param created_by: The created_by of this DebtCollectionReceipt.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this DebtCollectionReceipt.

            The date and time when the object was created.

        :return: The created_on of this DebtCollectionReceipt.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this DebtCollectionReceipt.

            The date and time when the object was created.

        :param created_on: The created_on of this DebtCollectionReceipt.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def debt_collection_case(self):
        """Gets the debt_collection_case of this DebtCollectionReceipt.

            The debt collection case that this document belongs to.

        :return: The debt_collection_case of this DebtCollectionReceipt.
        :rtype: int
        """
        return self._debt_collection_case

    @debt_collection_case.setter
    def debt_collection_case(self, debt_collection_case):
        """Sets the debt_collection_case of this DebtCollectionReceipt.

            The debt collection case that this document belongs to.

        :param debt_collection_case: The debt_collection_case of this DebtCollectionReceipt.
        :type: int
        """

        self._debt_collection_case = debt_collection_case
    
    @property
    def external_id(self):
        """Gets the external_id of this DebtCollectionReceipt.

            A client-generated nonce which uniquely identifies the receipt.Subsequent requests with the same external ID do not lead to the creation of another receipt, but return the original one.

        :return: The external_id of this DebtCollectionReceipt.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this DebtCollectionReceipt.

            A client-generated nonce which uniquely identifies the receipt.Subsequent requests with the same external ID do not lead to the creation of another receipt, but return the original one.

        :param external_id: The external_id of this DebtCollectionReceipt.
        :type: str
        """
        if external_id is not None and len(external_id) > 100:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `100`")
        if external_id is not None and len(external_id) < 1:
            raise ValueError("Invalid value for `external_id`, length must be greater than or equal to `1`")

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this DebtCollectionReceipt.

            A unique identifier for the object.

        :return: The id of this DebtCollectionReceipt.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DebtCollectionReceipt.

            A unique identifier for the object.

        :param id: The id of this DebtCollectionReceipt.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this DebtCollectionReceipt.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this DebtCollectionReceipt.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this DebtCollectionReceipt.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this DebtCollectionReceipt.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this DebtCollectionReceipt.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this DebtCollectionReceipt.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this DebtCollectionReceipt.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this DebtCollectionReceipt.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def source(self):
        """Gets the source of this DebtCollectionReceipt.

            The source stating where the receipt is coming from.

        :return: The source of this DebtCollectionReceipt.
        :rtype: int
        """
        return self._source

    @source.setter
    def source(self, source):
        """Sets the source of this DebtCollectionReceipt.

            The source stating where the receipt is coming from.

        :param source: The source of this DebtCollectionReceipt.
        :type: int
        """

        self._source = source
    
    @property
    def version(self):
        """Gets the version of this DebtCollectionReceipt.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this DebtCollectionReceipt.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this DebtCollectionReceipt.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this DebtCollectionReceipt.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(DebtCollectionReceipt, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, DebtCollectionReceipt):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum
from . import AbstractTransactionPending


class TransactionCreate(AbstractTransactionPending):

    swagger_types = {
    
        'auto_confirmation_enabled': 'bool',
        'charge_retry_enabled': 'bool',
        'customers_presence': 'CustomersPresence',
        'device_session_identifier': 'str',
        'emails_disabled': 'bool',
        'environment': 'Environment',
        'environment_selection_strategy': 'TransactionEnvironmentSelectionStrategy',
        'space_view_id': 'int',
    }

    attribute_map = {
        'auto_confirmation_enabled': 'autoConfirmationEnabled','charge_retry_enabled': 'chargeRetryEnabled','customers_presence': 'customersPresence','device_session_identifier': 'deviceSessionIdentifier','emails_disabled': 'emailsDisabled','environment': 'environment','environment_selection_strategy': 'environmentSelectionStrategy','space_view_id': 'spaceViewId',
    }

    
    _auto_confirmation_enabled = None
    _charge_retry_enabled = None
    _customers_presence = None
    _device_session_identifier = None
    _emails_disabled = None
    _environment = None
    _environment_selection_strategy = None
    _space_view_id = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.auto_confirmation_enabled = kwargs.get('auto_confirmation_enabled', None)
        self.charge_retry_enabled = kwargs.get('charge_retry_enabled', None)
        self.customers_presence = kwargs.get('customers_presence', None)
        self.device_session_identifier = kwargs.get('device_session_identifier', None)
        self.emails_disabled = kwargs.get('emails_disabled', None)
        self.environment = kwargs.get('environment', None)
        self.environment_selection_strategy = kwargs.get('environment_selection_strategy', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def auto_confirmation_enabled(self):
        """Gets the auto_confirmation_enabled of this TransactionCreate.

            Whether the transaction can be confirmed automatically or whether this must be done explicitly via the API. Default is true.

        :return: The auto_confirmation_enabled of this TransactionCreate.
        :rtype: bool
        """
        return self._auto_confirmation_enabled

    @auto_confirmation_enabled.setter
    def auto_confirmation_enabled(self, auto_confirmation_enabled):
        """Sets the auto_confirmation_enabled of this TransactionCreate.

            Whether the transaction can be confirmed automatically or whether this must be done explicitly via the API. Default is true.

        :param auto_confirmation_enabled: The auto_confirmation_enabled of this TransactionCreate.
        :type: bool
        """

        self._auto_confirmation_enabled = auto_confirmation_enabled
    
    @property
    def charge_retry_enabled(self):
        """Gets the charge_retry_enabled of this TransactionCreate.

            Whether the customer can make further payment attempts if the first one has failed. Default is true.

        :return: The charge_retry_enabled of this TransactionCreate.
        :rtype: bool
        """
        return self._charge_retry_enabled

    @charge_retry_enabled.setter
    def charge_retry_enabled(self, charge_retry_enabled):
        """Sets the charge_retry_enabled of this TransactionCreate.

            Whether the customer can make further payment attempts if the first one has failed. Default is true.

        :param charge_retry_enabled: The charge_retry_enabled of this TransactionCreate.
        :type: bool
        """

        self._charge_retry_enabled = charge_retry_enabled
    
    @property
    def customers_presence(self):
        """Gets the customers_presence of this TransactionCreate.

            The customer's presence indicates whether and in what way the transaction's customer is present. Default is VIRTUAL_PRESENT.

        :return: The customers_presence of this TransactionCreate.
        :rtype: CustomersPresence
        """
        return self._customers_presence

    @customers_presence.setter
    def customers_presence(self, customers_presence):
        """Sets the customers_presence of this TransactionCreate.

            The customer's presence indicates whether and in what way the transaction's customer is present. Default is VIRTUAL_PRESENT.

        :param customers_presence: The customers_presence of this TransactionCreate.
        :type: CustomersPresence
        """

        self._customers_presence = customers_presence
    
    @property
    def device_session_identifier(self):
        """Gets the device_session_identifier of this TransactionCreate.

            Allows to link the transaction to the data collected from the customer's device.

        :return: The device_session_identifier of this TransactionCreate.
        :rtype: str
        """
        return self._device_session_identifier

    @device_session_identifier.setter
    def device_session_identifier(self, device_session_identifier):
        """Sets the device_session_identifier of this TransactionCreate.

            Allows to link the transaction to the data collected from the customer's device.

        :param device_session_identifier: The device_session_identifier of this TransactionCreate.
        :type: str
        """
        if device_session_identifier is not None and len(device_session_identifier) > 40:
            raise ValueError("Invalid value for `device_session_identifier`, length must be less than or equal to `40`")
        if device_session_identifier is not None and len(device_session_identifier) < 10:
            raise ValueError("Invalid value for `device_session_identifier`, length must be greater than or equal to `10`")

        self._device_session_identifier = device_session_identifier
    
    @property
    def emails_disabled(self):
        """Gets the emails_disabled of this TransactionCreate.

            Whether email sending is deactivated for the transaction. Default is false.

        :return: The emails_disabled of this TransactionCreate.
        :rtype: bool
        """
        return self._emails_disabled

    @emails_disabled.setter
    def emails_disabled(self, emails_disabled):
        """Sets the emails_disabled of this TransactionCreate.

            Whether email sending is deactivated for the transaction. Default is false.

        :param emails_disabled: The emails_disabled of this TransactionCreate.
        :type: bool
        """

        self._emails_disabled = emails_disabled
    
    @property
    def environment(self):
        """Gets the environment of this TransactionCreate.

            The environment used when rendering resources.

        :return: The environment of this TransactionCreate.
        :rtype: Environment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this TransactionCreate.

            The environment used when rendering resources.

        :param environment: The environment of this TransactionCreate.
        :type: Environment
        """

        self._environment = environment
    
    @property
    def environment_selection_strategy(self):
        """Gets the environment_selection_strategy of this TransactionCreate.

            The strategy for determining whether the transaction is to be processed in the test or production environment.

        :return: The environment_selection_strategy of this TransactionCreate.
        :rtype: TransactionEnvironmentSelectionStrategy
        """
        return self._environment_selection_strategy

    @environment_selection_strategy.setter
    def environment_selection_strategy(self, environment_selection_strategy):
        """Sets the environment_selection_strategy of this TransactionCreate.

            The strategy for determining whether the transaction is to be processed in the test or production environment.

        :param environment_selection_strategy: The environment_selection_strategy of this TransactionCreate.
        :type: TransactionEnvironmentSelectionStrategy
        """

        self._environment_selection_strategy = environment_selection_strategy
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this TransactionCreate.

            The ID of the space view this object is linked to.

        :return: The space_view_id of this TransactionCreate.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this TransactionCreate.

            The ID of the space view this object is linked to.

        :param space_view_id: The space_view_id of this TransactionCreate.
        :type: int
        """

        self._space_view_id = space_view_id
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(TransactionCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, TransactionCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class DunningCaseLevel:

    swagger_types = {
    
        'canceled_on': 'datetime',
        'created_on': 'datetime',
        'dunning_case': 'DunningCase',
        'environment': 'Environment',
        'failed_on': 'datetime',
        'flow_level': 'int',
        'id': 'int',
        'invoice': 'int',
        'language': 'str',
        'linked_space_id': 'int',
        'linked_transaction': 'int',
        'most_recent_level': 'bool',
        'planned_purge_date': 'datetime',
        'state': 'DunningCaseLevelState',
        'succeeded_on': 'datetime',
        'timeout_on': 'datetime',
        'version': 'int',
    }

    attribute_map = {
        'canceled_on': 'canceledOn','created_on': 'createdOn','dunning_case': 'dunningCase','environment': 'environment','failed_on': 'failedOn','flow_level': 'flowLevel','id': 'id','invoice': 'invoice','language': 'language','linked_space_id': 'linkedSpaceId','linked_transaction': 'linkedTransaction','most_recent_level': 'mostRecentLevel','planned_purge_date': 'plannedPurgeDate','state': 'state','succeeded_on': 'succeededOn','timeout_on': 'timeoutOn','version': 'version',
    }

    
    _canceled_on = None
    _created_on = None
    _dunning_case = None
    _environment = None
    _failed_on = None
    _flow_level = None
    _id = None
    _invoice = None
    _language = None
    _linked_space_id = None
    _linked_transaction = None
    _most_recent_level = None
    _planned_purge_date = None
    _state = None
    _succeeded_on = None
    _timeout_on = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.canceled_on = kwargs.get('canceled_on', None)
        self.created_on = kwargs.get('created_on', None)
        self.dunning_case = kwargs.get('dunning_case', None)
        self.environment = kwargs.get('environment', None)
        self.failed_on = kwargs.get('failed_on', None)
        self.flow_level = kwargs.get('flow_level', None)
        self.id = kwargs.get('id', None)
        self.invoice = kwargs.get('invoice', None)
        self.language = kwargs.get('language', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.linked_transaction = kwargs.get('linked_transaction', None)
        self.most_recent_level = kwargs.get('most_recent_level', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.succeeded_on = kwargs.get('succeeded_on', None)
        self.timeout_on = kwargs.get('timeout_on', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def canceled_on(self):
        """Gets the canceled_on of this DunningCaseLevel.

            

        :return: The canceled_on of this DunningCaseLevel.
        :rtype: datetime
        """
        return self._canceled_on

    @canceled_on.setter
    def canceled_on(self, canceled_on):
        """Sets the canceled_on of this DunningCaseLevel.

            

        :param canceled_on: The canceled_on of this DunningCaseLevel.
        :type: datetime
        """

        self._canceled_on = canceled_on
    
    @property
    def created_on(self):
        """Gets the created_on of this DunningCaseLevel.

            The date and time when the object was created.

        :return: The created_on of this DunningCaseLevel.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this DunningCaseLevel.

            The date and time when the object was created.

        :param created_on: The created_on of this DunningCaseLevel.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def dunning_case(self):
        """Gets the dunning_case of this DunningCaseLevel.

            

        :return: The dunning_case of this DunningCaseLevel.
        :rtype: DunningCase
        """
        return self._dunning_case

    @dunning_case.setter
    def dunning_case(self, dunning_case):
        """Sets the dunning_case of this DunningCaseLevel.

            

        :param dunning_case: The dunning_case of this DunningCaseLevel.
        :type: DunningCase
        """

        self._dunning_case = dunning_case
    
    @property
    def environment(self):
        """Gets the environment of this DunningCaseLevel.

            The environment used when rendering resources.

        :return: The environment of this DunningCaseLevel.
        :rtype: Environment
        """
        return self._environment

    @environment.setter
    def environment(self, environment):
        """Sets the environment of this DunningCaseLevel.

            The environment used when rendering resources.

        :param environment: The environment of this DunningCaseLevel.
        :type: Environment
        """

        self._environment = environment
    
    @property
    def failed_on(self):
        """Gets the failed_on of this DunningCaseLevel.

            

        :return: The failed_on of this DunningCaseLevel.
        :rtype: datetime
        """
        return self._failed_on

    @failed_on.setter
    def failed_on(self, failed_on):
        """Sets the failed_on of this DunningCaseLevel.

            

        :param failed_on: The failed_on of this DunningCaseLevel.
        :type: datetime
        """

        self._failed_on = failed_on
    
    @property
    def flow_level(self):
        """Gets the flow_level of this DunningCaseLevel.

            

        :return: The flow_level of this DunningCaseLevel.
        :rtype: int
        """
        return self._flow_level

    @flow_level.setter
    def flow_level(self, flow_level):
        """Sets the flow_level of this DunningCaseLevel.

            

        :param flow_level: The flow_level of this DunningCaseLevel.
        :type: int
        """

        self._flow_level = flow_level
    
    @property
    def id(self):
        """Gets the id of this DunningCaseLevel.

            A unique identifier for the object.

        :return: The id of this DunningCaseLevel.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DunningCaseLevel.

            A unique identifier for the object.

        :param id: The id of this DunningCaseLevel.
        :type: int
        """

        self._id = id
    
    @property
    def invoice(self):
        """Gets the invoice of this DunningCaseLevel.

            

        :return: The invoice of this DunningCaseLevel.
        :rtype: int
        """
        return self._invoice

    @invoice.setter
    def invoice(self, invoice):
        """Sets the invoice of this DunningCaseLevel.

            

        :param invoice: The invoice of this DunningCaseLevel.
        :type: int
        """

        self._invoice = invoice
    
    @property
    def language(self):
        """Gets the language of this DunningCaseLevel.

            The language that is linked to the object.

        :return: The language of this DunningCaseLevel.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this DunningCaseLevel.

            The language that is linked to the object.

        :param language: The language of this DunningCaseLevel.
        :type: str
        """

        self._language = language
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this DunningCaseLevel.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this DunningCaseLevel.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this DunningCaseLevel.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this DunningCaseLevel.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def linked_transaction(self):
        """Gets the linked_transaction of this DunningCaseLevel.

            The payment transaction this object is linked to.

        :return: The linked_transaction of this DunningCaseLevel.
        :rtype: int
        """
        return self._linked_transaction

    @linked_transaction.setter
    def linked_transaction(self, linked_transaction):
        """Sets the linked_transaction of this DunningCaseLevel.

            The payment transaction this object is linked to.

        :param linked_transaction: The linked_transaction of this DunningCaseLevel.
        :type: int
        """

        self._linked_transaction = linked_transaction
    
    @property
    def most_recent_level(self):
        """Gets the most_recent_level of this DunningCaseLevel.

            

        :return: The most_recent_level of this DunningCaseLevel.
        :rtype: bool
        """
        return self._most_recent_level

    @most_recent_level.setter
    def most_recent_level(self, most_recent_level):
        """Sets the most_recent_level of this DunningCaseLevel.

            

        :param most_recent_level: The most_recent_level of this DunningCaseLevel.
        :type: bool
        """

        self._most_recent_level = most_recent_level
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this DunningCaseLevel.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this DunningCaseLevel.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this DunningCaseLevel.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this DunningCaseLevel.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this DunningCaseLevel.

            The object's current state.

        :return: The state of this DunningCaseLevel.
        :rtype: DunningCaseLevelState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this DunningCaseLevel.

            The object's current state.

        :param state: The state of this DunningCaseLevel.
        :type: DunningCaseLevelState
        """

        self._state = state
    
    @property
    def succeeded_on(self):
        """Gets the succeeded_on of this DunningCaseLevel.

            

        :return: The succeeded_on of this DunningCaseLevel.
        :rtype: datetime
        """
        return self._succeeded_on

    @succeeded_on.setter
    def succeeded_on(self, succeeded_on):
        """Sets the succeeded_on of this DunningCaseLevel.

            

        :param succeeded_on: The succeeded_on of this DunningCaseLevel.
        :type: datetime
        """

        self._succeeded_on = succeeded_on
    
    @property
    def timeout_on(self):
        """Gets the timeout_on of this DunningCaseLevel.

            

        :return: The timeout_on of this DunningCaseLevel.
        :rtype: datetime
        """
        return self._timeout_on

    @timeout_on.setter
    def timeout_on(self, timeout_on):
        """Sets the timeout_on of this DunningCaseLevel.

            

        :param timeout_on: The timeout_on of this DunningCaseLevel.
        :type: datetime
        """

        self._timeout_on = timeout_on
    
    @property
    def version(self):
        """Gets the version of this DunningCaseLevel.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this DunningCaseLevel.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this DunningCaseLevel.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this DunningCaseLevel.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(DunningCaseLevel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, DunningCaseLevel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionProductVersionPending:

    swagger_types = {
    
        'id': 'int',
        'version': 'int',
        'billing_cycle': 'str',
        'comment': 'str',
        'default_currency': 'str',
        'enabled_currencies': 'list[str]',
        'minimal_number_of_periods': 'int',
        'name': 'dict(str, str)',
        'number_of_notice_periods': 'int',
        'product': 'int',
        'state': 'SubscriptionProductVersionState',
        'tax_calculation': 'TaxCalculation',
    }

    attribute_map = {
        'id': 'id','version': 'version','billing_cycle': 'billingCycle','comment': 'comment','default_currency': 'defaultCurrency','enabled_currencies': 'enabledCurrencies','minimal_number_of_periods': 'minimalNumberOfPeriods','name': 'name','number_of_notice_periods': 'numberOfNoticePeriods','product': 'product','state': 'state','tax_calculation': 'taxCalculation',
    }

    
    _id = None
    _version = None
    _billing_cycle = None
    _comment = None
    _default_currency = None
    _enabled_currencies = None
    _minimal_number_of_periods = None
    _name = None
    _number_of_notice_periods = None
    _product = None
    _state = None
    _tax_calculation = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id')

        self.version = kwargs.get('version')

        self.billing_cycle = kwargs.get('billing_cycle', None)
        self.comment = kwargs.get('comment', None)
        self.default_currency = kwargs.get('default_currency', None)
        self.enabled_currencies = kwargs.get('enabled_currencies', None)
        self.minimal_number_of_periods = kwargs.get('minimal_number_of_periods', None)
        self.name = kwargs.get('name', None)
        self.number_of_notice_periods = kwargs.get('number_of_notice_periods', None)
        self.product = kwargs.get('product', None)
        self.state = kwargs.get('state', None)
        self.tax_calculation = kwargs.get('tax_calculation', None)
        

    
    @property
    def id(self):
        """Gets the id of this SubscriptionProductVersionPending.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this SubscriptionProductVersionPending.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this SubscriptionProductVersionPending.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this SubscriptionProductVersionPending.
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id
    
    @property
    def version(self):
        """Gets the version of this SubscriptionProductVersionPending.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this SubscriptionProductVersionPending.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this SubscriptionProductVersionPending.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this SubscriptionProductVersionPending.
        :type: int
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version
    
    @property
    def billing_cycle(self):
        """Gets the billing_cycle of this SubscriptionProductVersionPending.

            The recurring period of time, typically monthly or annually, for which a subscriber is charged.

        :return: The billing_cycle of this SubscriptionProductVersionPending.
        :rtype: str
        """
        return self._billing_cycle

    @billing_cycle.setter
    def billing_cycle(self, billing_cycle):
        """Sets the billing_cycle of this SubscriptionProductVersionPending.

            The recurring period of time, typically monthly or annually, for which a subscriber is charged.

        :param billing_cycle: The billing_cycle of this SubscriptionProductVersionPending.
        :type: str
        """

        self._billing_cycle = billing_cycle
    
    @property
    def comment(self):
        """Gets the comment of this SubscriptionProductVersionPending.

            A comment that describes the product version and why it was created. It is not disclosed to the subscriber.

        :return: The comment of this SubscriptionProductVersionPending.
        :rtype: str
        """
        return self._comment

    @comment.setter
    def comment(self, comment):
        """Sets the comment of this SubscriptionProductVersionPending.

            A comment that describes the product version and why it was created. It is not disclosed to the subscriber.

        :param comment: The comment of this SubscriptionProductVersionPending.
        :type: str
        """

        self._comment = comment
    
    @property
    def default_currency(self):
        """Gets the default_currency of this SubscriptionProductVersionPending.

            The three-letter code (ISO 4217 format) of the product version's default currency.

        :return: The default_currency of this SubscriptionProductVersionPending.
        :rtype: str
        """
        return self._default_currency

    @default_currency.setter
    def default_currency(self, default_currency):
        """Sets the default_currency of this SubscriptionProductVersionPending.

            The three-letter code (ISO 4217 format) of the product version's default currency.

        :param default_currency: The default_currency of this SubscriptionProductVersionPending.
        :type: str
        """

        self._default_currency = default_currency
    
    @property
    def enabled_currencies(self):
        """Gets the enabled_currencies of this SubscriptionProductVersionPending.

            The three-letter codes (ISO 4217 format) of the currencies that the product version supports.

        :return: The enabled_currencies of this SubscriptionProductVersionPending.
        :rtype: list[str]
        """
        return self._enabled_currencies

    @enabled_currencies.setter
    def enabled_currencies(self, enabled_currencies):
        """Sets the enabled_currencies of this SubscriptionProductVersionPending.

            The three-letter codes (ISO 4217 format) of the currencies that the product version supports.

        :param enabled_currencies: The enabled_currencies of this SubscriptionProductVersionPending.
        :type: list[str]
        """

        self._enabled_currencies = enabled_currencies
    
    @property
    def minimal_number_of_periods(self):
        """Gets the minimal_number_of_periods of this SubscriptionProductVersionPending.

            The minimum number of periods the subscription will run before it can be terminated.

        :return: The minimal_number_of_periods of this SubscriptionProductVersionPending.
        :rtype: int
        """
        return self._minimal_number_of_periods

    @minimal_number_of_periods.setter
    def minimal_number_of_periods(self, minimal_number_of_periods):
        """Sets the minimal_number_of_periods of this SubscriptionProductVersionPending.

            The minimum number of periods the subscription will run before it can be terminated.

        :param minimal_number_of_periods: The minimal_number_of_periods of this SubscriptionProductVersionPending.
        :type: int
        """

        self._minimal_number_of_periods = minimal_number_of_periods
    
    @property
    def name(self):
        """Gets the name of this SubscriptionProductVersionPending.

            The localized name of the product that is displayed to the customer.

        :return: The name of this SubscriptionProductVersionPending.
        :rtype: dict(str, str)
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this SubscriptionProductVersionPending.

            The localized name of the product that is displayed to the customer.

        :param name: The name of this SubscriptionProductVersionPending.
        :type: dict(str, str)
        """

        self._name = name
    
    @property
    def number_of_notice_periods(self):
        """Gets the number_of_notice_periods of this SubscriptionProductVersionPending.

            The number of periods the subscription will keep running after its termination was requested.

        :return: The number_of_notice_periods of this SubscriptionProductVersionPending.
        :rtype: int
        """
        return self._number_of_notice_periods

    @number_of_notice_periods.setter
    def number_of_notice_periods(self, number_of_notice_periods):
        """Sets the number_of_notice_periods of this SubscriptionProductVersionPending.

            The number of periods the subscription will keep running after its termination was requested.

        :param number_of_notice_periods: The number_of_notice_periods of this SubscriptionProductVersionPending.
        :type: int
        """

        self._number_of_notice_periods = number_of_notice_periods
    
    @property
    def product(self):
        """Gets the product of this SubscriptionProductVersionPending.

            The product that the version belongs to.

        :return: The product of this SubscriptionProductVersionPending.
        :rtype: int
        """
        return self._product

    @product.setter
    def product(self, product):
        """Sets the product of this SubscriptionProductVersionPending.

            The product that the version belongs to.

        :param product: The product of this SubscriptionProductVersionPending.
        :type: int
        """

        self._product = product
    
    @property
    def state(self):
        """Gets the state of this SubscriptionProductVersionPending.

            The object's current state.

        :return: The state of this SubscriptionProductVersionPending.
        :rtype: SubscriptionProductVersionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this SubscriptionProductVersionPending.

            The object's current state.

        :param state: The state of this SubscriptionProductVersionPending.
        :type: SubscriptionProductVersionState
        """

        self._state = state
    
    @property
    def tax_calculation(self):
        """Gets the tax_calculation of this SubscriptionProductVersionPending.

            The way taxes are calculated for fees.

        :return: The tax_calculation of this SubscriptionProductVersionPending.
        :rtype: TaxCalculation
        """
        return self._tax_calculation

    @tax_calculation.setter
    def tax_calculation(self, tax_calculation):
        """Sets the tax_calculation of this SubscriptionProductVersionPending.

            The way taxes are calculated for fees.

        :param tax_calculation: The tax_calculation of this SubscriptionProductVersionPending.
        :type: TaxCalculation
        """

        self._tax_calculation = tax_calculation
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionProductVersionPending, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionProductVersionPending):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
from enum import Enum, unique


@unique
class DunningCaseState(Enum):
    
    RUNNING = "RUNNING"
    SUSPENDED = "SUSPENDED"
    CANCELED = "CANCELED"
    DERECOGNIZED = "DERECOGNIZED"
    FAILED = "FAILED"
    SUCCEEDED = "SUCCEEDED"




# coding: utf-8
import pprint
import six
from enum import Enum
from . import AbstractWebhookListenerUpdate


class WebhookListenerCreate(AbstractWebhookListenerUpdate):

    swagger_types = {
    
        'entity': 'int',
        'identity': 'int',
        'url': 'int',
    }

    attribute_map = {
        'entity': 'entity','identity': 'identity','url': 'url',
    }

    
    _entity = None
    _identity = None
    _url = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.entity = kwargs.get('entity')

        self.identity = kwargs.get('identity', None)
        self.url = kwargs.get('url')

        super().__init__(**kwargs)
        self.swagger_types.update(super().swagger_types)
        self.attribute_map.update(super().attribute_map)

    
    @property
    def entity(self):
        """Gets the entity of this WebhookListenerCreate.

            The entity that is to be monitored.

        :return: The entity of this WebhookListenerCreate.
        :rtype: int
        """
        return self._entity

    @entity.setter
    def entity(self, entity):
        """Sets the entity of this WebhookListenerCreate.

            The entity that is to be monitored.

        :param entity: The entity of this WebhookListenerCreate.
        :type: int
        """
        if entity is None:
            raise ValueError("Invalid value for `entity`, must not be `None`")

        self._entity = entity
    
    @property
    def identity(self):
        """Gets the identity of this WebhookListenerCreate.

            The identity used to sign messages.

        :return: The identity of this WebhookListenerCreate.
        :rtype: int
        """
        return self._identity

    @identity.setter
    def identity(self, identity):
        """Sets the identity of this WebhookListenerCreate.

            The identity used to sign messages.

        :param identity: The identity of this WebhookListenerCreate.
        :type: int
        """

        self._identity = identity
    
    @property
    def url(self):
        """Gets the url of this WebhookListenerCreate.

            The URL where notifications about entity changes are sent to.

        :return: The url of this WebhookListenerCreate.
        :rtype: int
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this WebhookListenerCreate.

            The URL where notifications about entity changes are sent to.

        :param url: The url of this WebhookListenerCreate.
        :type: int
        """
        if url is None:
            raise ValueError("Invalid value for `url`, must not be `None`")

        self._url = url
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(WebhookListenerCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, WebhookListenerCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class DunningCase:

    swagger_types = {
    
        'canceled_on': 'datetime',
        'created_on': 'datetime',
        'derecognized_on': 'datetime',
        'failed_on': 'datetime',
        'flow': 'DunningFlow',
        'id': 'int',
        'initial_invoice': 'TransactionInvoice',
        'linked_space_id': 'int',
        'linked_transaction': 'int',
        'planned_purge_date': 'datetime',
        'state': 'DunningCaseState',
        'succeeded_on': 'datetime',
        'version': 'int',
    }

    attribute_map = {
        'canceled_on': 'canceledOn','created_on': 'createdOn','derecognized_on': 'derecognizedOn','failed_on': 'failedOn','flow': 'flow','id': 'id','initial_invoice': 'initialInvoice','linked_space_id': 'linkedSpaceId','linked_transaction': 'linkedTransaction','planned_purge_date': 'plannedPurgeDate','state': 'state','succeeded_on': 'succeededOn','version': 'version',
    }

    
    _canceled_on = None
    _created_on = None
    _derecognized_on = None
    _failed_on = None
    _flow = None
    _id = None
    _initial_invoice = None
    _linked_space_id = None
    _linked_transaction = None
    _planned_purge_date = None
    _state = None
    _succeeded_on = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.canceled_on = kwargs.get('canceled_on', None)
        self.created_on = kwargs.get('created_on', None)
        self.derecognized_on = kwargs.get('derecognized_on', None)
        self.failed_on = kwargs.get('failed_on', None)
        self.flow = kwargs.get('flow', None)
        self.id = kwargs.get('id', None)
        self.initial_invoice = kwargs.get('initial_invoice', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.linked_transaction = kwargs.get('linked_transaction', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.state = kwargs.get('state', None)
        self.succeeded_on = kwargs.get('succeeded_on', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def canceled_on(self):
        """Gets the canceled_on of this DunningCase.

            

        :return: The canceled_on of this DunningCase.
        :rtype: datetime
        """
        return self._canceled_on

    @canceled_on.setter
    def canceled_on(self, canceled_on):
        """Sets the canceled_on of this DunningCase.

            

        :param canceled_on: The canceled_on of this DunningCase.
        :type: datetime
        """

        self._canceled_on = canceled_on
    
    @property
    def created_on(self):
        """Gets the created_on of this DunningCase.

            The date and time when the object was created.

        :return: The created_on of this DunningCase.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this DunningCase.

            The date and time when the object was created.

        :param created_on: The created_on of this DunningCase.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def derecognized_on(self):
        """Gets the derecognized_on of this DunningCase.

            

        :return: The derecognized_on of this DunningCase.
        :rtype: datetime
        """
        return self._derecognized_on

    @derecognized_on.setter
    def derecognized_on(self, derecognized_on):
        """Sets the derecognized_on of this DunningCase.

            

        :param derecognized_on: The derecognized_on of this DunningCase.
        :type: datetime
        """

        self._derecognized_on = derecognized_on
    
    @property
    def failed_on(self):
        """Gets the failed_on of this DunningCase.

            

        :return: The failed_on of this DunningCase.
        :rtype: datetime
        """
        return self._failed_on

    @failed_on.setter
    def failed_on(self, failed_on):
        """Sets the failed_on of this DunningCase.

            

        :param failed_on: The failed_on of this DunningCase.
        :type: datetime
        """

        self._failed_on = failed_on
    
    @property
    def flow(self):
        """Gets the flow of this DunningCase.

            

        :return: The flow of this DunningCase.
        :rtype: DunningFlow
        """
        return self._flow

    @flow.setter
    def flow(self, flow):
        """Sets the flow of this DunningCase.

            

        :param flow: The flow of this DunningCase.
        :type: DunningFlow
        """

        self._flow = flow
    
    @property
    def id(self):
        """Gets the id of this DunningCase.

            A unique identifier for the object.

        :return: The id of this DunningCase.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DunningCase.

            A unique identifier for the object.

        :param id: The id of this DunningCase.
        :type: int
        """

        self._id = id
    
    @property
    def initial_invoice(self):
        """Gets the initial_invoice of this DunningCase.

            

        :return: The initial_invoice of this DunningCase.
        :rtype: TransactionInvoice
        """
        return self._initial_invoice

    @initial_invoice.setter
    def initial_invoice(self, initial_invoice):
        """Sets the initial_invoice of this DunningCase.

            

        :param initial_invoice: The initial_invoice of this DunningCase.
        :type: TransactionInvoice
        """

        self._initial_invoice = initial_invoice
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this DunningCase.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this DunningCase.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this DunningCase.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this DunningCase.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def linked_transaction(self):
        """Gets the linked_transaction of this DunningCase.

            The payment transaction this object is linked to.

        :return: The linked_transaction of this DunningCase.
        :rtype: int
        """
        return self._linked_transaction

    @linked_transaction.setter
    def linked_transaction(self, linked_transaction):
        """Sets the linked_transaction of this DunningCase.

            The payment transaction this object is linked to.

        :param linked_transaction: The linked_transaction of this DunningCase.
        :type: int
        """

        self._linked_transaction = linked_transaction
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this DunningCase.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this DunningCase.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this DunningCase.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this DunningCase.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def state(self):
        """Gets the state of this DunningCase.

            The object's current state.

        :return: The state of this DunningCase.
        :rtype: DunningCaseState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this DunningCase.

            The object's current state.

        :param state: The state of this DunningCase.
        :type: DunningCaseState
        """

        self._state = state
    
    @property
    def succeeded_on(self):
        """Gets the succeeded_on of this DunningCase.

            

        :return: The succeeded_on of this DunningCase.
        :rtype: datetime
        """
        return self._succeeded_on

    @succeeded_on.setter
    def succeeded_on(self, succeeded_on):
        """Sets the succeeded_on of this DunningCase.

            

        :param succeeded_on: The succeeded_on of this DunningCase.
        :type: datetime
        """

        self._succeeded_on = succeeded_on
    
    @property
    def version(self):
        """Gets the version of this DunningCase.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this DunningCase.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this DunningCase.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this DunningCase.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(DunningCase, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, DunningCase):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class ProductMeteredTierFeeUpdate:

    swagger_types = {
    
        'id': 'int',
        'version': 'int',
        'fee': 'list[PersistableCurrencyAmountUpdate]',
        'metered_fee': 'int',
        'start_range': 'float',
    }

    attribute_map = {
        'id': 'id','version': 'version','fee': 'fee','metered_fee': 'meteredFee','start_range': 'startRange',
    }

    
    _id = None
    _version = None
    _fee = None
    _metered_fee = None
    _start_range = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.id = kwargs.get('id')

        self.version = kwargs.get('version')

        self.fee = kwargs.get('fee', None)
        self.metered_fee = kwargs.get('metered_fee', None)
        self.start_range = kwargs.get('start_range', None)
        

    
    @property
    def id(self):
        """Gets the id of this ProductMeteredTierFeeUpdate.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :return: The id of this ProductMeteredTierFeeUpdate.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ProductMeteredTierFeeUpdate.

            The ID is the primary key of the entity. The ID identifies the entity uniquely.

        :param id: The id of this ProductMeteredTierFeeUpdate.
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id
    
    @property
    def version(self):
        """Gets the version of this ProductMeteredTierFeeUpdate.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :return: The version of this ProductMeteredTierFeeUpdate.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this ProductMeteredTierFeeUpdate.

            The version number indicates the version of the entity. The version is incremented whenever the entity is changed.

        :param version: The version of this ProductMeteredTierFeeUpdate.
        :type: int
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")

        self._version = version
    
    @property
    def fee(self):
        """Gets the fee of this ProductMeteredTierFeeUpdate.

            The amount charged to the customer for each consumed unit at the end of a billing cycle.

        :return: The fee of this ProductMeteredTierFeeUpdate.
        :rtype: list[PersistableCurrencyAmountUpdate]
        """
        return self._fee

    @fee.setter
    def fee(self, fee):
        """Sets the fee of this ProductMeteredTierFeeUpdate.

            The amount charged to the customer for each consumed unit at the end of a billing cycle.

        :param fee: The fee of this ProductMeteredTierFeeUpdate.
        :type: list[PersistableCurrencyAmountUpdate]
        """

        self._fee = fee
    
    @property
    def metered_fee(self):
        """Gets the metered_fee of this ProductMeteredTierFeeUpdate.

            The metered fee that this tier belongs to.

        :return: The metered_fee of this ProductMeteredTierFeeUpdate.
        :rtype: int
        """
        return self._metered_fee

    @metered_fee.setter
    def metered_fee(self, metered_fee):
        """Sets the metered_fee of this ProductMeteredTierFeeUpdate.

            The metered fee that this tier belongs to.

        :param metered_fee: The metered_fee of this ProductMeteredTierFeeUpdate.
        :type: int
        """

        self._metered_fee = metered_fee
    
    @property
    def start_range(self):
        """Gets the start_range of this ProductMeteredTierFeeUpdate.

            Starting from and including this quantity is contained in the tier.

        :return: The start_range of this ProductMeteredTierFeeUpdate.
        :rtype: float
        """
        return self._start_range

    @start_range.setter
    def start_range(self, start_range):
        """Sets the start_range of this ProductMeteredTierFeeUpdate.

            Starting from and including this quantity is contained in the tier.

        :param start_range: The start_range of this ProductMeteredTierFeeUpdate.
        :type: float
        """

        self._start_range = start_range
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(ProductMeteredTierFeeUpdate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, ProductMeteredTierFeeUpdate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class TransactionCompletion:

    swagger_types = {
    
        'amount': 'float',
        'base_line_items': 'list[LineItem]',
        'created_by': 'int',
        'created_on': 'datetime',
        'external_id': 'str',
        'failed_on': 'datetime',
        'failure_reason': 'FailureReason',
        'id': 'int',
        'invoice_merchant_reference': 'str',
        'labels': 'list[Label]',
        'language': 'str',
        'last_completion': 'bool',
        'line_item_version': 'TransactionLineItemVersion',
        'line_items': 'list[LineItem]',
        'linked_space_id': 'int',
        'linked_transaction': 'int',
        'mode': 'TransactionCompletionMode',
        'next_update_on': 'datetime',
        'payment_information': 'str',
        'planned_purge_date': 'datetime',
        'processing_on': 'datetime',
        'processor_reference': 'str',
        'remaining_line_items': 'list[LineItem]',
        'space_view_id': 'int',
        'state': 'TransactionCompletionState',
        'statement_descriptor': 'str',
        'succeeded_on': 'datetime',
        'tax_amount': 'float',
        'time_zone': 'str',
        'timeout_on': 'datetime',
        'version': 'int',
    }

    attribute_map = {
        'amount': 'amount','base_line_items': 'baseLineItems','created_by': 'createdBy','created_on': 'createdOn','external_id': 'externalId','failed_on': 'failedOn','failure_reason': 'failureReason','id': 'id','invoice_merchant_reference': 'invoiceMerchantReference','labels': 'labels','language': 'language','last_completion': 'lastCompletion','line_item_version': 'lineItemVersion','line_items': 'lineItems','linked_space_id': 'linkedSpaceId','linked_transaction': 'linkedTransaction','mode': 'mode','next_update_on': 'nextUpdateOn','payment_information': 'paymentInformation','planned_purge_date': 'plannedPurgeDate','processing_on': 'processingOn','processor_reference': 'processorReference','remaining_line_items': 'remainingLineItems','space_view_id': 'spaceViewId','state': 'state','statement_descriptor': 'statementDescriptor','succeeded_on': 'succeededOn','tax_amount': 'taxAmount','time_zone': 'timeZone','timeout_on': 'timeoutOn','version': 'version',
    }

    
    _amount = None
    _base_line_items = None
    _created_by = None
    _created_on = None
    _external_id = None
    _failed_on = None
    _failure_reason = None
    _id = None
    _invoice_merchant_reference = None
    _labels = None
    _language = None
    _last_completion = None
    _line_item_version = None
    _line_items = None
    _linked_space_id = None
    _linked_transaction = None
    _mode = None
    _next_update_on = None
    _payment_information = None
    _planned_purge_date = None
    _processing_on = None
    _processor_reference = None
    _remaining_line_items = None
    _space_view_id = None
    _state = None
    _statement_descriptor = None
    _succeeded_on = None
    _tax_amount = None
    _time_zone = None
    _timeout_on = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.amount = kwargs.get('amount', None)
        self.base_line_items = kwargs.get('base_line_items', None)
        self.created_by = kwargs.get('created_by', None)
        self.created_on = kwargs.get('created_on', None)
        self.external_id = kwargs.get('external_id', None)
        self.failed_on = kwargs.get('failed_on', None)
        self.failure_reason = kwargs.get('failure_reason', None)
        self.id = kwargs.get('id', None)
        self.invoice_merchant_reference = kwargs.get('invoice_merchant_reference', None)
        self.labels = kwargs.get('labels', None)
        self.language = kwargs.get('language', None)
        self.last_completion = kwargs.get('last_completion', None)
        self.line_item_version = kwargs.get('line_item_version', None)
        self.line_items = kwargs.get('line_items', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.linked_transaction = kwargs.get('linked_transaction', None)
        self.mode = kwargs.get('mode', None)
        self.next_update_on = kwargs.get('next_update_on', None)
        self.payment_information = kwargs.get('payment_information', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.processing_on = kwargs.get('processing_on', None)
        self.processor_reference = kwargs.get('processor_reference', None)
        self.remaining_line_items = kwargs.get('remaining_line_items', None)
        self.space_view_id = kwargs.get('space_view_id', None)
        self.state = kwargs.get('state', None)
        self.statement_descriptor = kwargs.get('statement_descriptor', None)
        self.succeeded_on = kwargs.get('succeeded_on', None)
        self.tax_amount = kwargs.get('tax_amount', None)
        self.time_zone = kwargs.get('time_zone', None)
        self.timeout_on = kwargs.get('timeout_on', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def amount(self):
        """Gets the amount of this TransactionCompletion.

            The total amount to be captured in this completion, including taxes.

        :return: The amount of this TransactionCompletion.
        :rtype: float
        """
        return self._amount

    @amount.setter
    def amount(self, amount):
        """Sets the amount of this TransactionCompletion.

            The total amount to be captured in this completion, including taxes.

        :param amount: The amount of this TransactionCompletion.
        :type: float
        """

        self._amount = amount
    
    @property
    def base_line_items(self):
        """Gets the base_line_items of this TransactionCompletion.

            The original line items from the transaction that serve as the baseline for this completion.

        :return: The base_line_items of this TransactionCompletion.
        :rtype: list[LineItem]
        """
        return self._base_line_items

    @base_line_items.setter
    def base_line_items(self, base_line_items):
        """Sets the base_line_items of this TransactionCompletion.

            The original line items from the transaction that serve as the baseline for this completion.

        :param base_line_items: The base_line_items of this TransactionCompletion.
        :type: list[LineItem]
        """

        self._base_line_items = base_line_items
    
    @property
    def created_by(self):
        """Gets the created_by of this TransactionCompletion.

            The ID of the user the transaction completion was created by.

        :return: The created_by of this TransactionCompletion.
        :rtype: int
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this TransactionCompletion.

            The ID of the user the transaction completion was created by.

        :param created_by: The created_by of this TransactionCompletion.
        :type: int
        """

        self._created_by = created_by
    
    @property
    def created_on(self):
        """Gets the created_on of this TransactionCompletion.

            The date and time when the object was created.

        :return: The created_on of this TransactionCompletion.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this TransactionCompletion.

            The date and time when the object was created.

        :param created_on: The created_on of this TransactionCompletion.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def external_id(self):
        """Gets the external_id of this TransactionCompletion.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :return: The external_id of this TransactionCompletion.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this TransactionCompletion.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :param external_id: The external_id of this TransactionCompletion.
        :type: str
        """
        if external_id is not None and len(external_id) > 100:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `100`")
        if external_id is not None and len(external_id) < 1:
            raise ValueError("Invalid value for `external_id`, length must be greater than or equal to `1`")

        self._external_id = external_id
    
    @property
    def failed_on(self):
        """Gets the failed_on of this TransactionCompletion.

            The date and time when the transaction completion failed.

        :return: The failed_on of this TransactionCompletion.
        :rtype: datetime
        """
        return self._failed_on

    @failed_on.setter
    def failed_on(self, failed_on):
        """Sets the failed_on of this TransactionCompletion.

            The date and time when the transaction completion failed.

        :param failed_on: The failed_on of this TransactionCompletion.
        :type: datetime
        """

        self._failed_on = failed_on
    
    @property
    def failure_reason(self):
        """Gets the failure_reason of this TransactionCompletion.

            The reason for the failure of the transaction completion.

        :return: The failure_reason of this TransactionCompletion.
        :rtype: FailureReason
        """
        return self._failure_reason

    @failure_reason.setter
    def failure_reason(self, failure_reason):
        """Sets the failure_reason of this TransactionCompletion.

            The reason for the failure of the transaction completion.

        :param failure_reason: The failure_reason of this TransactionCompletion.
        :type: FailureReason
        """

        self._failure_reason = failure_reason
    
    @property
    def id(self):
        """Gets the id of this TransactionCompletion.

            A unique identifier for the object.

        :return: The id of this TransactionCompletion.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this TransactionCompletion.

            A unique identifier for the object.

        :param id: The id of this TransactionCompletion.
        :type: int
        """

        self._id = id
    
    @property
    def invoice_merchant_reference(self):
        """Gets the invoice_merchant_reference of this TransactionCompletion.

            The merchant's reference used to identify the invoice.

        :return: The invoice_merchant_reference of this TransactionCompletion.
        :rtype: str
        """
        return self._invoice_merchant_reference

    @invoice_merchant_reference.setter
    def invoice_merchant_reference(self, invoice_merchant_reference):
        """Sets the invoice_merchant_reference of this TransactionCompletion.

            The merchant's reference used to identify the invoice.

        :param invoice_merchant_reference: The invoice_merchant_reference of this TransactionCompletion.
        :type: str
        """
        if invoice_merchant_reference is not None and len(invoice_merchant_reference) > 100:
            raise ValueError("Invalid value for `invoice_merchant_reference`, length must be less than or equal to `100`")

        self._invoice_merchant_reference = invoice_merchant_reference
    
    @property
    def labels(self):
        """Gets the labels of this TransactionCompletion.

            The labels providing additional information about the object.

        :return: The labels of this TransactionCompletion.
        :rtype: list[Label]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """Sets the labels of this TransactionCompletion.

            The labels providing additional information about the object.

        :param labels: The labels of this TransactionCompletion.
        :type: list[Label]
        """

        self._labels = labels
    
    @property
    def language(self):
        """Gets the language of this TransactionCompletion.

            The language that is linked to the object.

        :return: The language of this TransactionCompletion.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this TransactionCompletion.

            The language that is linked to the object.

        :param language: The language of this TransactionCompletion.
        :type: str
        """

        self._language = language
    
    @property
    def last_completion(self):
        """Gets the last_completion of this TransactionCompletion.

            Whether this is the final completion for the transaction. After the last completion is successfully created, the transaction enters its final state, and no further completions can occur.

        :return: The last_completion of this TransactionCompletion.
        :rtype: bool
        """
        return self._last_completion

    @last_completion.setter
    def last_completion(self, last_completion):
        """Sets the last_completion of this TransactionCompletion.

            Whether this is the final completion for the transaction. After the last completion is successfully created, the transaction enters its final state, and no further completions can occur.

        :param last_completion: The last_completion of this TransactionCompletion.
        :type: bool
        """

        self._last_completion = last_completion
    
    @property
    def line_item_version(self):
        """Gets the line_item_version of this TransactionCompletion.

            The specific version of the line items that are being used for this completion.

        :return: The line_item_version of this TransactionCompletion.
        :rtype: TransactionLineItemVersion
        """
        return self._line_item_version

    @line_item_version.setter
    def line_item_version(self, line_item_version):
        """Sets the line_item_version of this TransactionCompletion.

            The specific version of the line items that are being used for this completion.

        :param line_item_version: The line_item_version of this TransactionCompletion.
        :type: TransactionLineItemVersion
        """

        self._line_item_version = line_item_version
    
    @property
    def line_items(self):
        """Gets the line_items of this TransactionCompletion.

            The line items captured in this transaction completion.

        :return: The line_items of this TransactionCompletion.
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this TransactionCompletion.

            The line items captured in this transaction completion.

        :param line_items: The line_items of this TransactionCompletion.
        :type: list[LineItem]
        """

        self._line_items = line_items
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this TransactionCompletion.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this TransactionCompletion.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this TransactionCompletion.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this TransactionCompletion.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def linked_transaction(self):
        """Gets the linked_transaction of this TransactionCompletion.

            The payment transaction this object is linked to.

        :return: The linked_transaction of this TransactionCompletion.
        :rtype: int
        """
        return self._linked_transaction

    @linked_transaction.setter
    def linked_transaction(self, linked_transaction):
        """Sets the linked_transaction of this TransactionCompletion.

            The payment transaction this object is linked to.

        :param linked_transaction: The linked_transaction of this TransactionCompletion.
        :type: int
        """

        self._linked_transaction = linked_transaction
    
    @property
    def mode(self):
        """Gets the mode of this TransactionCompletion.

            The mode of transaction completion, such as online or offline, determining how the completion process is executed.

        :return: The mode of this TransactionCompletion.
        :rtype: TransactionCompletionMode
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """Sets the mode of this TransactionCompletion.

            The mode of transaction completion, such as online or offline, determining how the completion process is executed.

        :param mode: The mode of this TransactionCompletion.
        :type: TransactionCompletionMode
        """

        self._mode = mode
    
    @property
    def next_update_on(self):
        """Gets the next_update_on of this TransactionCompletion.

            The date and time when the next update of the object's state is planned.

        :return: The next_update_on of this TransactionCompletion.
        :rtype: datetime
        """
        return self._next_update_on

    @next_update_on.setter
    def next_update_on(self, next_update_on):
        """Sets the next_update_on of this TransactionCompletion.

            The date and time when the next update of the object's state is planned.

        :param next_update_on: The next_update_on of this TransactionCompletion.
        :type: datetime
        """

        self._next_update_on = next_update_on
    
    @property
    def payment_information(self):
        """Gets the payment_information of this TransactionCompletion.

            Payment-specific details related to this transaction completion such as payment instructions or references needed for processing.

        :return: The payment_information of this TransactionCompletion.
        :rtype: str
        """
        return self._payment_information

    @payment_information.setter
    def payment_information(self, payment_information):
        """Sets the payment_information of this TransactionCompletion.

            Payment-specific details related to this transaction completion such as payment instructions or references needed for processing.

        :param payment_information: The payment_information of this TransactionCompletion.
        :type: str
        """

        self._payment_information = payment_information
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this TransactionCompletion.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this TransactionCompletion.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this TransactionCompletion.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this TransactionCompletion.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def processing_on(self):
        """Gets the processing_on of this TransactionCompletion.

            The date and time when the processing of the transaction completion was started.

        :return: The processing_on of this TransactionCompletion.
        :rtype: datetime
        """
        return self._processing_on

    @processing_on.setter
    def processing_on(self, processing_on):
        """Sets the processing_on of this TransactionCompletion.

            The date and time when the processing of the transaction completion was started.

        :param processing_on: The processing_on of this TransactionCompletion.
        :type: datetime
        """

        self._processing_on = processing_on
    
    @property
    def processor_reference(self):
        """Gets the processor_reference of this TransactionCompletion.

            The reference ID provided by the payment processor, used to trace the completion through the external payment system.

        :return: The processor_reference of this TransactionCompletion.
        :rtype: str
        """
        return self._processor_reference

    @processor_reference.setter
    def processor_reference(self, processor_reference):
        """Sets the processor_reference of this TransactionCompletion.

            The reference ID provided by the payment processor, used to trace the completion through the external payment system.

        :param processor_reference: The processor_reference of this TransactionCompletion.
        :type: str
        """

        self._processor_reference = processor_reference
    
    @property
    def remaining_line_items(self):
        """Gets the remaining_line_items of this TransactionCompletion.

            The line items yet to be captured in the transaction.

        :return: The remaining_line_items of this TransactionCompletion.
        :rtype: list[LineItem]
        """
        return self._remaining_line_items

    @remaining_line_items.setter
    def remaining_line_items(self, remaining_line_items):
        """Sets the remaining_line_items of this TransactionCompletion.

            The line items yet to be captured in the transaction.

        :param remaining_line_items: The remaining_line_items of this TransactionCompletion.
        :type: list[LineItem]
        """

        self._remaining_line_items = remaining_line_items
    
    @property
    def space_view_id(self):
        """Gets the space_view_id of this TransactionCompletion.

            The ID of the space view this object is linked to.

        :return: The space_view_id of this TransactionCompletion.
        :rtype: int
        """
        return self._space_view_id

    @space_view_id.setter
    def space_view_id(self, space_view_id):
        """Sets the space_view_id of this TransactionCompletion.

            The ID of the space view this object is linked to.

        :param space_view_id: The space_view_id of this TransactionCompletion.
        :type: int
        """

        self._space_view_id = space_view_id
    
    @property
    def state(self):
        """Gets the state of this TransactionCompletion.

            The object's current state.

        :return: The state of this TransactionCompletion.
        :rtype: TransactionCompletionState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this TransactionCompletion.

            The object's current state.

        :param state: The state of this TransactionCompletion.
        :type: TransactionCompletionState
        """

        self._state = state
    
    @property
    def statement_descriptor(self):
        """Gets the statement_descriptor of this TransactionCompletion.

            The statement descriptor that appears on a customer's bank statement, providing an explanation for charges or payments, helping customers identify the transaction.

        :return: The statement_descriptor of this TransactionCompletion.
        :rtype: str
        """
        return self._statement_descriptor

    @statement_descriptor.setter
    def statement_descriptor(self, statement_descriptor):
        """Sets the statement_descriptor of this TransactionCompletion.

            The statement descriptor that appears on a customer's bank statement, providing an explanation for charges or payments, helping customers identify the transaction.

        :param statement_descriptor: The statement_descriptor of this TransactionCompletion.
        :type: str
        """
        if statement_descriptor is not None and len(statement_descriptor) > 80:
            raise ValueError("Invalid value for `statement_descriptor`, length must be less than or equal to `80`")

        self._statement_descriptor = statement_descriptor
    
    @property
    def succeeded_on(self):
        """Gets the succeeded_on of this TransactionCompletion.

            The date and time when the transaction completion succeeded.

        :return: The succeeded_on of this TransactionCompletion.
        :rtype: datetime
        """
        return self._succeeded_on

    @succeeded_on.setter
    def succeeded_on(self, succeeded_on):
        """Sets the succeeded_on of this TransactionCompletion.

            The date and time when the transaction completion succeeded.

        :param succeeded_on: The succeeded_on of this TransactionCompletion.
        :type: datetime
        """

        self._succeeded_on = succeeded_on
    
    @property
    def tax_amount(self):
        """Gets the tax_amount of this TransactionCompletion.

            The portion of the captured amount that corresponds to taxes.

        :return: The tax_amount of this TransactionCompletion.
        :rtype: float
        """
        return self._tax_amount

    @tax_amount.setter
    def tax_amount(self, tax_amount):
        """Sets the tax_amount of this TransactionCompletion.

            The portion of the captured amount that corresponds to taxes.

        :param tax_amount: The tax_amount of this TransactionCompletion.
        :type: float
        """

        self._tax_amount = tax_amount
    
    @property
    def time_zone(self):
        """Gets the time_zone of this TransactionCompletion.

            The time zone that this object is associated with.

        :return: The time_zone of this TransactionCompletion.
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this TransactionCompletion.

            The time zone that this object is associated with.

        :param time_zone: The time_zone of this TransactionCompletion.
        :type: str
        """

        self._time_zone = time_zone
    
    @property
    def timeout_on(self):
        """Gets the timeout_on of this TransactionCompletion.

            The date and time when the object will expire.

        :return: The timeout_on of this TransactionCompletion.
        :rtype: datetime
        """
        return self._timeout_on

    @timeout_on.setter
    def timeout_on(self, timeout_on):
        """Sets the timeout_on of this TransactionCompletion.

            The date and time when the object will expire.

        :param timeout_on: The timeout_on of this TransactionCompletion.
        :type: datetime
        """

        self._timeout_on = timeout_on
    
    @property
    def version(self):
        """Gets the version of this TransactionCompletion.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this TransactionCompletion.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this TransactionCompletion.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this TransactionCompletion.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(TransactionCompletion, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, TransactionCompletion):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentLink:

    swagger_types = {
    
        'allowed_payment_method_configurations': 'list[PaymentMethodConfiguration]',
        'allowed_redirection_domains': 'list[str]',
        'applied_space_view': 'int',
        'available_from': 'datetime',
        'available_until': 'datetime',
        'billing_address_handling_mode': 'PaymentLinkAddressHandlingMode',
        'currency': 'str',
        'external_id': 'str',
        'id': 'int',
        'language': 'str',
        'line_items': 'list[LineItem]',
        'linked_space_id': 'int',
        'maximal_number_of_transactions': 'int',
        'name': 'str',
        'planned_purge_date': 'datetime',
        'protection_mode': 'PaymentLinkProtectionMode',
        'shipping_address_handling_mode': 'PaymentLinkAddressHandlingMode',
        'state': 'CreationEntityState',
        'url': 'str',
        'version': 'int',
    }

    attribute_map = {
        'allowed_payment_method_configurations': 'allowedPaymentMethodConfigurations','allowed_redirection_domains': 'allowedRedirectionDomains','applied_space_view': 'appliedSpaceView','available_from': 'availableFrom','available_until': 'availableUntil','billing_address_handling_mode': 'billingAddressHandlingMode','currency': 'currency','external_id': 'externalId','id': 'id','language': 'language','line_items': 'lineItems','linked_space_id': 'linkedSpaceId','maximal_number_of_transactions': 'maximalNumberOfTransactions','name': 'name','planned_purge_date': 'plannedPurgeDate','protection_mode': 'protectionMode','shipping_address_handling_mode': 'shippingAddressHandlingMode','state': 'state','url': 'url','version': 'version',
    }

    
    _allowed_payment_method_configurations = None
    _allowed_redirection_domains = None
    _applied_space_view = None
    _available_from = None
    _available_until = None
    _billing_address_handling_mode = None
    _currency = None
    _external_id = None
    _id = None
    _language = None
    _line_items = None
    _linked_space_id = None
    _maximal_number_of_transactions = None
    _name = None
    _planned_purge_date = None
    _protection_mode = None
    _shipping_address_handling_mode = None
    _state = None
    _url = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.allowed_payment_method_configurations = kwargs.get('allowed_payment_method_configurations', None)
        self.allowed_redirection_domains = kwargs.get('allowed_redirection_domains', None)
        self.applied_space_view = kwargs.get('applied_space_view', None)
        self.available_from = kwargs.get('available_from', None)
        self.available_until = kwargs.get('available_until', None)
        self.billing_address_handling_mode = kwargs.get('billing_address_handling_mode', None)
        self.currency = kwargs.get('currency', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.language = kwargs.get('language', None)
        self.line_items = kwargs.get('line_items', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.maximal_number_of_transactions = kwargs.get('maximal_number_of_transactions', None)
        self.name = kwargs.get('name', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.protection_mode = kwargs.get('protection_mode', None)
        self.shipping_address_handling_mode = kwargs.get('shipping_address_handling_mode', None)
        self.state = kwargs.get('state', None)
        self.url = kwargs.get('url', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def allowed_payment_method_configurations(self):
        """Gets the allowed_payment_method_configurations of this PaymentLink.

            The payment method configurations that customers can use for making payments.

        :return: The allowed_payment_method_configurations of this PaymentLink.
        :rtype: list[PaymentMethodConfiguration]
        """
        return self._allowed_payment_method_configurations

    @allowed_payment_method_configurations.setter
    def allowed_payment_method_configurations(self, allowed_payment_method_configurations):
        """Sets the allowed_payment_method_configurations of this PaymentLink.

            The payment method configurations that customers can use for making payments.

        :param allowed_payment_method_configurations: The allowed_payment_method_configurations of this PaymentLink.
        :type: list[PaymentMethodConfiguration]
        """

        self._allowed_payment_method_configurations = allowed_payment_method_configurations
    
    @property
    def allowed_redirection_domains(self):
        """Gets the allowed_redirection_domains of this PaymentLink.

            The domains to which the user is allowed to be redirected after the payment is completed. The following options can be configured: Exact domain: enter a full domain, e.g. (https://example.com). Wildcard domain: use to allow subdomains, e.g. (https://*.example.com). All domains: use (ALL) to allow redirection to any domain (not recommended for security reasons). No domains : use (NONE) to disallow any redirection. Only one option per line is allowed. Invalid entries will be rejected. 

        :return: The allowed_redirection_domains of this PaymentLink.
        :rtype: list[str]
        """
        return self._allowed_redirection_domains

    @allowed_redirection_domains.setter
    def allowed_redirection_domains(self, allowed_redirection_domains):
        """Sets the allowed_redirection_domains of this PaymentLink.

            The domains to which the user is allowed to be redirected after the payment is completed. The following options can be configured: Exact domain: enter a full domain, e.g. (https://example.com). Wildcard domain: use to allow subdomains, e.g. (https://*.example.com). All domains: use (ALL) to allow redirection to any domain (not recommended for security reasons). No domains : use (NONE) to disallow any redirection. Only one option per line is allowed. Invalid entries will be rejected. 

        :param allowed_redirection_domains: The allowed_redirection_domains of this PaymentLink.
        :type: list[str]
        """

        self._allowed_redirection_domains = allowed_redirection_domains
    
    @property
    def applied_space_view(self):
        """Gets the applied_space_view of this PaymentLink.

            The payment link can be used within a specific space view, which may apply a customized design to the payment page.

        :return: The applied_space_view of this PaymentLink.
        :rtype: int
        """
        return self._applied_space_view

    @applied_space_view.setter
    def applied_space_view(self, applied_space_view):
        """Sets the applied_space_view of this PaymentLink.

            The payment link can be used within a specific space view, which may apply a customized design to the payment page.

        :param applied_space_view: The applied_space_view of this PaymentLink.
        :type: int
        """

        self._applied_space_view = applied_space_view
    
    @property
    def available_from(self):
        """Gets the available_from of this PaymentLink.

            The earliest date the payment link can be used to initiate a transaction. If no date is provided, the link will be available immediately.

        :return: The available_from of this PaymentLink.
        :rtype: datetime
        """
        return self._available_from

    @available_from.setter
    def available_from(self, available_from):
        """Sets the available_from of this PaymentLink.

            The earliest date the payment link can be used to initiate a transaction. If no date is provided, the link will be available immediately.

        :param available_from: The available_from of this PaymentLink.
        :type: datetime
        """

        self._available_from = available_from
    
    @property
    def available_until(self):
        """Gets the available_until of this PaymentLink.

            The latest date the payment link can be used to initiate a transaction. If no date is provided, the link will remain available indefinitely.

        :return: The available_until of this PaymentLink.
        :rtype: datetime
        """
        return self._available_until

    @available_until.setter
    def available_until(self, available_until):
        """Sets the available_until of this PaymentLink.

            The latest date the payment link can be used to initiate a transaction. If no date is provided, the link will remain available indefinitely.

        :param available_until: The available_until of this PaymentLink.
        :type: datetime
        """

        self._available_until = available_until
    
    @property
    def billing_address_handling_mode(self):
        """Gets the billing_address_handling_mode of this PaymentLink.

            The handling mode defines whether a billing address is required and specifies how it should be provided.

        :return: The billing_address_handling_mode of this PaymentLink.
        :rtype: PaymentLinkAddressHandlingMode
        """
        return self._billing_address_handling_mode

    @billing_address_handling_mode.setter
    def billing_address_handling_mode(self, billing_address_handling_mode):
        """Sets the billing_address_handling_mode of this PaymentLink.

            The handling mode defines whether a billing address is required and specifies how it should be provided.

        :param billing_address_handling_mode: The billing_address_handling_mode of this PaymentLink.
        :type: PaymentLinkAddressHandlingMode
        """

        self._billing_address_handling_mode = billing_address_handling_mode
    
    @property
    def currency(self):
        """Gets the currency of this PaymentLink.

            The three-letter currency code (ISO 4217). If not specified, it must be provided in the 'currency' request parameter.

        :return: The currency of this PaymentLink.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """Sets the currency of this PaymentLink.

            The three-letter currency code (ISO 4217). If not specified, it must be provided in the 'currency' request parameter.

        :param currency: The currency of this PaymentLink.
        :type: str
        """

        self._currency = currency
    
    @property
    def external_id(self):
        """Gets the external_id of this PaymentLink.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :return: The external_id of this PaymentLink.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this PaymentLink.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :param external_id: The external_id of this PaymentLink.
        :type: str
        """

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this PaymentLink.

            A unique identifier for the object.

        :return: The id of this PaymentLink.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentLink.

            A unique identifier for the object.

        :param id: The id of this PaymentLink.
        :type: int
        """

        self._id = id
    
    @property
    def language(self):
        """Gets the language of this PaymentLink.

            The language for displaying the payment page. If not specified, it can be supplied via the 'language' request parameter.

        :return: The language of this PaymentLink.
        :rtype: str
        """
        return self._language

    @language.setter
    def language(self, language):
        """Sets the language of this PaymentLink.

            The language for displaying the payment page. If not specified, it can be supplied via the 'language' request parameter.

        :param language: The language of this PaymentLink.
        :type: str
        """

        self._language = language
    
    @property
    def line_items(self):
        """Gets the line_items of this PaymentLink.

            The line items representing what is being sold. If not specified, they can be supplied via request parameters.

        :return: The line_items of this PaymentLink.
        :rtype: list[LineItem]
        """
        return self._line_items

    @line_items.setter
    def line_items(self, line_items):
        """Sets the line_items of this PaymentLink.

            The line items representing what is being sold. If not specified, they can be supplied via request parameters.

        :param line_items: The line_items of this PaymentLink.
        :type: list[LineItem]
        """

        self._line_items = line_items
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentLink.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this PaymentLink.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentLink.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this PaymentLink.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def maximal_number_of_transactions(self):
        """Gets the maximal_number_of_transactions of this PaymentLink.

            The maximum number of transactions that can be initiated using the payment link.

        :return: The maximal_number_of_transactions of this PaymentLink.
        :rtype: int
        """
        return self._maximal_number_of_transactions

    @maximal_number_of_transactions.setter
    def maximal_number_of_transactions(self, maximal_number_of_transactions):
        """Sets the maximal_number_of_transactions of this PaymentLink.

            The maximum number of transactions that can be initiated using the payment link.

        :param maximal_number_of_transactions: The maximal_number_of_transactions of this PaymentLink.
        :type: int
        """

        self._maximal_number_of_transactions = maximal_number_of_transactions
    
    @property
    def name(self):
        """Gets the name of this PaymentLink.

            The name used to identify the payment link.

        :return: The name of this PaymentLink.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentLink.

            The name used to identify the payment link.

        :param name: The name of this PaymentLink.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this PaymentLink.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this PaymentLink.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this PaymentLink.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this PaymentLink.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def protection_mode(self):
        """Gets the protection_mode of this PaymentLink.

            The protection mode defines whether the payment link is protected against tampering and specifies the protection method.

        :return: The protection_mode of this PaymentLink.
        :rtype: PaymentLinkProtectionMode
        """
        return self._protection_mode

    @protection_mode.setter
    def protection_mode(self, protection_mode):
        """Sets the protection_mode of this PaymentLink.

            The protection mode defines whether the payment link is protected against tampering and specifies the protection method.

        :param protection_mode: The protection_mode of this PaymentLink.
        :type: PaymentLinkProtectionMode
        """

        self._protection_mode = protection_mode
    
    @property
    def shipping_address_handling_mode(self):
        """Gets the shipping_address_handling_mode of this PaymentLink.

            The handling mode defines whether a shipping address is required and specifies how it should be provided.

        :return: The shipping_address_handling_mode of this PaymentLink.
        :rtype: PaymentLinkAddressHandlingMode
        """
        return self._shipping_address_handling_mode

    @shipping_address_handling_mode.setter
    def shipping_address_handling_mode(self, shipping_address_handling_mode):
        """Sets the shipping_address_handling_mode of this PaymentLink.

            The handling mode defines whether a shipping address is required and specifies how it should be provided.

        :param shipping_address_handling_mode: The shipping_address_handling_mode of this PaymentLink.
        :type: PaymentLinkAddressHandlingMode
        """

        self._shipping_address_handling_mode = shipping_address_handling_mode
    
    @property
    def state(self):
        """Gets the state of this PaymentLink.

            The object's current state.

        :return: The state of this PaymentLink.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentLink.

            The object's current state.

        :param state: The state of this PaymentLink.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def url(self):
        """Gets the url of this PaymentLink.

            The public URL to share with customers for making payments.

        :return: The url of this PaymentLink.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this PaymentLink.

            The public URL to share with customers for making payments.

        :param url: The url of this PaymentLink.
        :type: str
        """

        self._url = url
    
    @property
    def version(self):
        """Gets the version of this PaymentLink.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this PaymentLink.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentLink.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this PaymentLink.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentLink, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentLink):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class DunningFlowLevel:

    swagger_types = {
    
        'document_text': 'dict(str, str)',
        'flow': 'DunningFlow',
        'id': 'int',
        'linked_space_id': 'int',
        'name': 'str',
        'period': 'str',
        'planned_purge_date': 'datetime',
        'priority': 'int',
        'processor': 'int',
        'reminder_template': 'DocumentTemplate',
        'state': 'CreationEntityState',
        'title': 'dict(str, str)',
        'version': 'int',
    }

    attribute_map = {
        'document_text': 'documentText','flow': 'flow','id': 'id','linked_space_id': 'linkedSpaceId','name': 'name','period': 'period','planned_purge_date': 'plannedPurgeDate','priority': 'priority','processor': 'processor','reminder_template': 'reminderTemplate','state': 'state','title': 'title','version': 'version',
    }

    
    _document_text = None
    _flow = None
    _id = None
    _linked_space_id = None
    _name = None
    _period = None
    _planned_purge_date = None
    _priority = None
    _processor = None
    _reminder_template = None
    _state = None
    _title = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.document_text = kwargs.get('document_text', None)
        self.flow = kwargs.get('flow', None)
        self.id = kwargs.get('id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.period = kwargs.get('period', None)
        self.planned_purge_date = kwargs.get('planned_purge_date', None)
        self.priority = kwargs.get('priority', None)
        self.processor = kwargs.get('processor', None)
        self.reminder_template = kwargs.get('reminder_template', None)
        self.state = kwargs.get('state', None)
        self.title = kwargs.get('title', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def document_text(self):
        """Gets the document_text of this DunningFlowLevel.

            This text is put in the reminder document of this dunning flow level.

        :return: The document_text of this DunningFlowLevel.
        :rtype: dict(str, str)
        """
        return self._document_text

    @document_text.setter
    def document_text(self, document_text):
        """Sets the document_text of this DunningFlowLevel.

            This text is put in the reminder document of this dunning flow level.

        :param document_text: The document_text of this DunningFlowLevel.
        :type: dict(str, str)
        """

        self._document_text = document_text
    
    @property
    def flow(self):
        """Gets the flow of this DunningFlowLevel.

            

        :return: The flow of this DunningFlowLevel.
        :rtype: DunningFlow
        """
        return self._flow

    @flow.setter
    def flow(self, flow):
        """Sets the flow of this DunningFlowLevel.

            

        :param flow: The flow of this DunningFlowLevel.
        :type: DunningFlow
        """

        self._flow = flow
    
    @property
    def id(self):
        """Gets the id of this DunningFlowLevel.

            A unique identifier for the object.

        :return: The id of this DunningFlowLevel.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this DunningFlowLevel.

            A unique identifier for the object.

        :param id: The id of this DunningFlowLevel.
        :type: int
        """

        self._id = id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this DunningFlowLevel.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this DunningFlowLevel.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this DunningFlowLevel.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this DunningFlowLevel.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this DunningFlowLevel.

            The dunning flow level name is used internally to identify the dunning flow level. For example the name is used within search fields and hence it should be distinct and descriptive.

        :return: The name of this DunningFlowLevel.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this DunningFlowLevel.

            The dunning flow level name is used internally to identify the dunning flow level. For example the name is used within search fields and hence it should be distinct and descriptive.

        :param name: The name of this DunningFlowLevel.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def period(self):
        """Gets the period of this DunningFlowLevel.

            The duration of the level before switching to the next one.

        :return: The period of this DunningFlowLevel.
        :rtype: str
        """
        return self._period

    @period.setter
    def period(self, period):
        """Sets the period of this DunningFlowLevel.

            The duration of the level before switching to the next one.

        :param period: The period of this DunningFlowLevel.
        :type: str
        """

        self._period = period
    
    @property
    def planned_purge_date(self):
        """Gets the planned_purge_date of this DunningFlowLevel.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :return: The planned_purge_date of this DunningFlowLevel.
        :rtype: datetime
        """
        return self._planned_purge_date

    @planned_purge_date.setter
    def planned_purge_date(self, planned_purge_date):
        """Sets the planned_purge_date of this DunningFlowLevel.

            The date and time when the object is planned to be permanently removed. If the value is empty, the object will not be removed.

        :param planned_purge_date: The planned_purge_date of this DunningFlowLevel.
        :type: datetime
        """

        self._planned_purge_date = planned_purge_date
    
    @property
    def priority(self):
        """Gets the priority of this DunningFlowLevel.

            The priority indicates the sort order of the level. A low value indicates that the level is executed before any level with a higher value. Any change to this value affects future level selections. The value has to pe unique per dunning flow.

        :return: The priority of this DunningFlowLevel.
        :rtype: int
        """
        return self._priority

    @priority.setter
    def priority(self, priority):
        """Sets the priority of this DunningFlowLevel.

            The priority indicates the sort order of the level. A low value indicates that the level is executed before any level with a higher value. Any change to this value affects future level selections. The value has to pe unique per dunning flow.

        :param priority: The priority of this DunningFlowLevel.
        :type: int
        """

        self._priority = priority
    
    @property
    def processor(self):
        """Gets the processor of this DunningFlowLevel.

            

        :return: The processor of this DunningFlowLevel.
        :rtype: int
        """
        return self._processor

    @processor.setter
    def processor(self, processor):
        """Sets the processor of this DunningFlowLevel.

            

        :param processor: The processor of this DunningFlowLevel.
        :type: int
        """

        self._processor = processor
    
    @property
    def reminder_template(self):
        """Gets the reminder_template of this DunningFlowLevel.

            

        :return: The reminder_template of this DunningFlowLevel.
        :rtype: DocumentTemplate
        """
        return self._reminder_template

    @reminder_template.setter
    def reminder_template(self, reminder_template):
        """Sets the reminder_template of this DunningFlowLevel.

            

        :param reminder_template: The reminder_template of this DunningFlowLevel.
        :type: DocumentTemplate
        """

        self._reminder_template = reminder_template
    
    @property
    def state(self):
        """Gets the state of this DunningFlowLevel.

            The object's current state.

        :return: The state of this DunningFlowLevel.
        :rtype: CreationEntityState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this DunningFlowLevel.

            The object's current state.

        :param state: The state of this DunningFlowLevel.
        :type: CreationEntityState
        """

        self._state = state
    
    @property
    def title(self):
        """Gets the title of this DunningFlowLevel.

            The title is used to communicate the dunning level to the customer within the reminder.

        :return: The title of this DunningFlowLevel.
        :rtype: dict(str, str)
        """
        return self._title

    @title.setter
    def title(self, title):
        """Sets the title of this DunningFlowLevel.

            The title is used to communicate the dunning level to the customer within the reminder.

        :param title: The title of this DunningFlowLevel.
        :type: dict(str, str)
        """

        self._title = title
    
    @property
    def version(self):
        """Gets the version of this DunningFlowLevel.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this DunningFlowLevel.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this DunningFlowLevel.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this DunningFlowLevel.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(DunningFlowLevel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, DunningFlowLevel):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class PaymentAppProcessor:

    swagger_types = {
    
        'configured_environment': 'ChargeAttemptEnvironment',
        'created_on': 'datetime',
        'documentation_url': 'str',
        'external_id': 'str',
        'id': 'int',
        'installation_id': 'int',
        'linked_space_id': 'int',
        'name': 'str',
        'processor_configuration': 'PaymentProcessorConfiguration',
        'production_mode_url': 'str',
        'state': 'PaymentAppProcessorState',
        'svg_icon': 'str',
        'updated_on': 'datetime',
        'usable_in_production': 'bool',
        'usable_in_production_since': 'datetime',
        'version': 'int',
    }

    attribute_map = {
        'configured_environment': 'configuredEnvironment','created_on': 'createdOn','documentation_url': 'documentationUrl','external_id': 'externalId','id': 'id','installation_id': 'installationId','linked_space_id': 'linkedSpaceId','name': 'name','processor_configuration': 'processorConfiguration','production_mode_url': 'productionModeUrl','state': 'state','svg_icon': 'svgIcon','updated_on': 'updatedOn','usable_in_production': 'usableInProduction','usable_in_production_since': 'usableInProductionSince','version': 'version',
    }

    
    _configured_environment = None
    _created_on = None
    _documentation_url = None
    _external_id = None
    _id = None
    _installation_id = None
    _linked_space_id = None
    _name = None
    _processor_configuration = None
    _production_mode_url = None
    _state = None
    _svg_icon = None
    _updated_on = None
    _usable_in_production = None
    _usable_in_production_since = None
    _version = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.configured_environment = kwargs.get('configured_environment', None)
        self.created_on = kwargs.get('created_on', None)
        self.documentation_url = kwargs.get('documentation_url', None)
        self.external_id = kwargs.get('external_id', None)
        self.id = kwargs.get('id', None)
        self.installation_id = kwargs.get('installation_id', None)
        self.linked_space_id = kwargs.get('linked_space_id', None)
        self.name = kwargs.get('name', None)
        self.processor_configuration = kwargs.get('processor_configuration', None)
        self.production_mode_url = kwargs.get('production_mode_url', None)
        self.state = kwargs.get('state', None)
        self.svg_icon = kwargs.get('svg_icon', None)
        self.updated_on = kwargs.get('updated_on', None)
        self.usable_in_production = kwargs.get('usable_in_production', None)
        self.usable_in_production_since = kwargs.get('usable_in_production_since', None)
        self.version = kwargs.get('version', None)
        

    
    @property
    def configured_environment(self):
        """Gets the configured_environment of this PaymentAppProcessor.

            The environment (e.g., test or production) currently configured for the processor.

        :return: The configured_environment of this PaymentAppProcessor.
        :rtype: ChargeAttemptEnvironment
        """
        return self._configured_environment

    @configured_environment.setter
    def configured_environment(self, configured_environment):
        """Sets the configured_environment of this PaymentAppProcessor.

            The environment (e.g., test or production) currently configured for the processor.

        :param configured_environment: The configured_environment of this PaymentAppProcessor.
        :type: ChargeAttemptEnvironment
        """

        self._configured_environment = configured_environment
    
    @property
    def created_on(self):
        """Gets the created_on of this PaymentAppProcessor.

            The date and time when the processor was created.

        :return: The created_on of this PaymentAppProcessor.
        :rtype: datetime
        """
        return self._created_on

    @created_on.setter
    def created_on(self, created_on):
        """Sets the created_on of this PaymentAppProcessor.

            The date and time when the processor was created.

        :param created_on: The created_on of this PaymentAppProcessor.
        :type: datetime
        """

        self._created_on = created_on
    
    @property
    def documentation_url(self):
        """Gets the documentation_url of this PaymentAppProcessor.

            A URL pointing to the documentation that explains how to configure and use the processor.

        :return: The documentation_url of this PaymentAppProcessor.
        :rtype: str
        """
        return self._documentation_url

    @documentation_url.setter
    def documentation_url(self, documentation_url):
        """Sets the documentation_url of this PaymentAppProcessor.

            A URL pointing to the documentation that explains how to configure and use the processor.

        :param documentation_url: The documentation_url of this PaymentAppProcessor.
        :type: str
        """

        self._documentation_url = documentation_url
    
    @property
    def external_id(self):
        """Gets the external_id of this PaymentAppProcessor.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :return: The external_id of this PaymentAppProcessor.
        :rtype: str
        """
        return self._external_id

    @external_id.setter
    def external_id(self, external_id):
        """Sets the external_id of this PaymentAppProcessor.

            A client-generated nonce which uniquely identifies some action to be executed. Subsequent requests with the same external ID do not execute the action again, but return the original result.

        :param external_id: The external_id of this PaymentAppProcessor.
        :type: str
        """
        if external_id is not None and len(external_id) > 40:
            raise ValueError("Invalid value for `external_id`, length must be less than or equal to `40`")

        self._external_id = external_id
    
    @property
    def id(self):
        """Gets the id of this PaymentAppProcessor.

            A unique identifier for the object.

        :return: The id of this PaymentAppProcessor.
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PaymentAppProcessor.

            A unique identifier for the object.

        :param id: The id of this PaymentAppProcessor.
        :type: int
        """

        self._id = id
    
    @property
    def installation_id(self):
        """Gets the installation_id of this PaymentAppProcessor.

            The installation ID identifies the Web App installation.

        :return: The installation_id of this PaymentAppProcessor.
        :rtype: int
        """
        return self._installation_id

    @installation_id.setter
    def installation_id(self, installation_id):
        """Sets the installation_id of this PaymentAppProcessor.

            The installation ID identifies the Web App installation.

        :param installation_id: The installation_id of this PaymentAppProcessor.
        :type: int
        """

        self._installation_id = installation_id
    
    @property
    def linked_space_id(self):
        """Gets the linked_space_id of this PaymentAppProcessor.

            The ID of the space this object belongs to.

        :return: The linked_space_id of this PaymentAppProcessor.
        :rtype: int
        """
        return self._linked_space_id

    @linked_space_id.setter
    def linked_space_id(self, linked_space_id):
        """Sets the linked_space_id of this PaymentAppProcessor.

            The ID of the space this object belongs to.

        :param linked_space_id: The linked_space_id of this PaymentAppProcessor.
        :type: int
        """

        self._linked_space_id = linked_space_id
    
    @property
    def name(self):
        """Gets the name of this PaymentAppProcessor.

            The name used to identify the processor.

        :return: The name of this PaymentAppProcessor.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this PaymentAppProcessor.

            The name used to identify the processor.

        :param name: The name of this PaymentAppProcessor.
        :type: str
        """
        if name is not None and len(name) > 100:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `100`")

        self._name = name
    
    @property
    def processor_configuration(self):
        """Gets the processor_configuration of this PaymentAppProcessor.

            The processor configuration created alongside the process within its designated space. This configuration is used in transactions created using this processor.

        :return: The processor_configuration of this PaymentAppProcessor.
        :rtype: PaymentProcessorConfiguration
        """
        return self._processor_configuration

    @processor_configuration.setter
    def processor_configuration(self, processor_configuration):
        """Sets the processor_configuration of this PaymentAppProcessor.

            The processor configuration created alongside the process within its designated space. This configuration is used in transactions created using this processor.

        :param processor_configuration: The processor_configuration of this PaymentAppProcessor.
        :type: PaymentProcessorConfiguration
        """

        self._processor_configuration = processor_configuration
    
    @property
    def production_mode_url(self):
        """Gets the production_mode_url of this PaymentAppProcessor.

            A URL pointing to the site where merchants can set up production mode for the processor.

        :return: The production_mode_url of this PaymentAppProcessor.
        :rtype: str
        """
        return self._production_mode_url

    @production_mode_url.setter
    def production_mode_url(self, production_mode_url):
        """Sets the production_mode_url of this PaymentAppProcessor.

            A URL pointing to the site where merchants can set up production mode for the processor.

        :param production_mode_url: The production_mode_url of this PaymentAppProcessor.
        :type: str
        """

        self._production_mode_url = production_mode_url
    
    @property
    def state(self):
        """Gets the state of this PaymentAppProcessor.

            The object's current state.

        :return: The state of this PaymentAppProcessor.
        :rtype: PaymentAppProcessorState
        """
        return self._state

    @state.setter
    def state(self, state):
        """Sets the state of this PaymentAppProcessor.

            The object's current state.

        :param state: The state of this PaymentAppProcessor.
        :type: PaymentAppProcessorState
        """

        self._state = state
    
    @property
    def svg_icon(self):
        """Gets the svg_icon of this PaymentAppProcessor.

            An SVG icon representing the processor, displayed to the user in the interface.

        :return: The svg_icon of this PaymentAppProcessor.
        :rtype: str
        """
        return self._svg_icon

    @svg_icon.setter
    def svg_icon(self, svg_icon):
        """Sets the svg_icon of this PaymentAppProcessor.

            An SVG icon representing the processor, displayed to the user in the interface.

        :param svg_icon: The svg_icon of this PaymentAppProcessor.
        :type: str
        """
        if svg_icon is not None and len(svg_icon) > 10000:
            raise ValueError("Invalid value for `svg_icon`, length must be less than or equal to `10000`")

        self._svg_icon = svg_icon
    
    @property
    def updated_on(self):
        """Gets the updated_on of this PaymentAppProcessor.

            The date and time when the processor was last updated.

        :return: The updated_on of this PaymentAppProcessor.
        :rtype: datetime
        """
        return self._updated_on

    @updated_on.setter
    def updated_on(self, updated_on):
        """Sets the updated_on of this PaymentAppProcessor.

            The date and time when the processor was last updated.

        :param updated_on: The updated_on of this PaymentAppProcessor.
        :type: datetime
        """

        self._updated_on = updated_on
    
    @property
    def usable_in_production(self):
        """Gets the usable_in_production of this PaymentAppProcessor.

            Whether the processor is fully prepared and available for handling transactions in a production environment.

        :return: The usable_in_production of this PaymentAppProcessor.
        :rtype: bool
        """
        return self._usable_in_production

    @usable_in_production.setter
    def usable_in_production(self, usable_in_production):
        """Sets the usable_in_production of this PaymentAppProcessor.

            Whether the processor is fully prepared and available for handling transactions in a production environment.

        :param usable_in_production: The usable_in_production of this PaymentAppProcessor.
        :type: bool
        """

        self._usable_in_production = usable_in_production
    
    @property
    def usable_in_production_since(self):
        """Gets the usable_in_production_since of this PaymentAppProcessor.

            the date and time when the processor became fully usable and available for handling transactions in a production environment.

        :return: The usable_in_production_since of this PaymentAppProcessor.
        :rtype: datetime
        """
        return self._usable_in_production_since

    @usable_in_production_since.setter
    def usable_in_production_since(self, usable_in_production_since):
        """Sets the usable_in_production_since of this PaymentAppProcessor.

            the date and time when the processor became fully usable and available for handling transactions in a production environment.

        :param usable_in_production_since: The usable_in_production_since of this PaymentAppProcessor.
        :type: datetime
        """

        self._usable_in_production_since = usable_in_production_since
    
    @property
    def version(self):
        """Gets the version of this PaymentAppProcessor.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :return: The version of this PaymentAppProcessor.
        :rtype: int
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this PaymentAppProcessor.

            The version is used for optimistic locking and incremented whenever the object is updated.

        :param version: The version of this PaymentAppProcessor.
        :type: int
        """

        self._version = version
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(PaymentAppProcessor, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, PaymentAppProcessor):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
import pprint
import six
from enum import Enum



class SubscriptionSuspensionCreate:

    swagger_types = {
    
        'end_action': 'SubscriptionSuspensionAction',
        'note': 'str',
        'planned_end_date': 'datetime',
        'subscription': 'int',
    }

    attribute_map = {
        'end_action': 'endAction','note': 'note','planned_end_date': 'plannedEndDate','subscription': 'subscription',
    }

    
    _end_action = None
    _note = None
    _planned_end_date = None
    _subscription = None

    def __init__(self, **kwargs):
        self.discriminator = None
        
        self.end_action = kwargs.get('end_action')

        self.note = kwargs.get('note', None)
        self.planned_end_date = kwargs.get('planned_end_date')

        self.subscription = kwargs.get('subscription')

        

    
    @property
    def end_action(self):
        """Gets the end_action of this SubscriptionSuspensionCreate.

            Whether the subscription should be terminated or reactivated after the suspension has reached its end date.

        :return: The end_action of this SubscriptionSuspensionCreate.
        :rtype: SubscriptionSuspensionAction
        """
        return self._end_action

    @end_action.setter
    def end_action(self, end_action):
        """Sets the end_action of this SubscriptionSuspensionCreate.

            Whether the subscription should be terminated or reactivated after the suspension has reached its end date.

        :param end_action: The end_action of this SubscriptionSuspensionCreate.
        :type: SubscriptionSuspensionAction
        """
        if end_action is None:
            raise ValueError("Invalid value for `end_action`, must not be `None`")

        self._end_action = end_action
    
    @property
    def note(self):
        """Gets the note of this SubscriptionSuspensionCreate.

            A note that contains details about the suspension. It is not disclosed to the subscriber.

        :return: The note of this SubscriptionSuspensionCreate.
        :rtype: str
        """
        return self._note

    @note.setter
    def note(self, note):
        """Sets the note of this SubscriptionSuspensionCreate.

            A note that contains details about the suspension. It is not disclosed to the subscriber.

        :param note: The note of this SubscriptionSuspensionCreate.
        :type: str
        """
        if note is not None and len(note) > 300:
            raise ValueError("Invalid value for `note`, length must be less than or equal to `300`")

        self._note = note
    
    @property
    def planned_end_date(self):
        """Gets the planned_end_date of this SubscriptionSuspensionCreate.

            The date and time when the suspension is planned to end.

        :return: The planned_end_date of this SubscriptionSuspensionCreate.
        :rtype: datetime
        """
        return self._planned_end_date

    @planned_end_date.setter
    def planned_end_date(self, planned_end_date):
        """Sets the planned_end_date of this SubscriptionSuspensionCreate.

            The date and time when the suspension is planned to end.

        :param planned_end_date: The planned_end_date of this SubscriptionSuspensionCreate.
        :type: datetime
        """
        if planned_end_date is None:
            raise ValueError("Invalid value for `planned_end_date`, must not be `None`")

        self._planned_end_date = planned_end_date
    
    @property
    def subscription(self):
        """Gets the subscription of this SubscriptionSuspensionCreate.

            The subscription that this suspension belongs to.

        :return: The subscription of this SubscriptionSuspensionCreate.
        :rtype: int
        """
        return self._subscription

    @subscription.setter
    def subscription(self, subscription):
        """Sets the subscription of this SubscriptionSuspensionCreate.

            The subscription that this suspension belongs to.

        :param subscription: The subscription of this SubscriptionSuspensionCreate.
        :type: int
        """
        if subscription is None:
            raise ValueError("Invalid value for `subscription`, must not be `None`")

        self._subscription = subscription
    

    def to_dict(self):
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            elif isinstance(value, Enum):
                result[attr] = value.value
            else:
                result[attr] = value
        if issubclass(SubscriptionSuspensionCreate, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        return self.to_str()

    def __eq__(self, other):
        if not isinstance(other, SubscriptionSuspensionCreate):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
